# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from typing import Set, Tuple

class FileFormatPopupBase(PopupFormWidget):
    def __init__(self, formats, parent, valuePolicy, widgetFactory) -> None: ...
    def _FileFormatPopupBase__externalSetValueCallback(self, event): ...
    def _FileFormatPopupBase__updateFormat(self): ...
    def getWidgetHints(self): ...
    def setFilename(self, name): ...
    def validFormats(self): ...

class InputFileFormatPopup(FileFormatPopupBase):
    def __init__(self, *args) -> None: ...
    def formatFromFilename(self, filename): ...
    def isOutput(self): ...

class OutputFileFormatPopup(FileFormatPopupBase):
    def __init__(self, *args) -> None: ...
    def formatFromFilename(self, filename): ...
    def isOutput(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.App.KeyboardShortcutManager.KeyboardShortcutManager as KeyboardShortcutManager
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import sip
import typing
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class KeyboardShortcutManagerMixin:
    def __init__(self, *args, **kwargs) -> None: ...
    def _installEventFilterForChildWidgets(self): ...
    def eventFilter(self, obj: QObject, event: QEvent) -> bool: ...
    @classmethod
    def getShortcutsContextName(cls) -> str: ...
    @classmethod
    def registerKeyboardShortcut(cls, shortcutID: str, name: str, shortcut: str, keyPressCallback: typing.Optional[typing.Callable] = ..., keyReleaseCallback: typing.Optional[typing.Callable] = ..., data: Incomplete | None = ...): ...
    @classmethod
    def setShortcutsContextName(cls, name: str): ...

class KeyboardShortcutManagerMixinMetaclass(sip.wrappertype):
    _KeyboardShortcutManagerMixinMetaclass__reservedNames: ClassVar[tuple] = ...
    def __init__(self, name: str, bases: tuple[type, ...], dct: dict) -> None: ...
    def __call__(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI.RenderNodeUtil as RenderNodeUtil
import Nodes3DAPI.Rendering as Rendering
import RenderingAPI as RenderingAPI
import Nodes3DAPI.RenderingUtil as RenderingUtil
import Utils as Utils
from typing import Set, Tuple

class MergeOutputs:
    def __init__(self) -> None: ...

class RenderNode:
    def __init__(self, node: NodegraphAPI.Node, graphState: NodegraphAPI.GraphState) -> None: ...
    def _RenderNode__addRenderOutputEnabledStatesToRecipe(self, txn, op, enabledOutputNames): ...
    def _RenderNode__addRenderTargetLocationsToRecipe(self, txn, op, renderTargetLocations, finalRenderTargetLocations): ...
    def _RenderNode__addTempFileInformationToRecipe(self, txn, op): ...
    def _RenderNode__buildCommandLines(self): ...
    def _RenderNode__getAttrValueOrEmptyString(self, attr): ...
    def _RenderNode__processMergeOutputs(self, outputName, outputInfo, client, mergedOutputs): ...
    def _RenderNode__processOutputs(self, client, op): ...
    def _RenderNode__processPreScriptOutput(self, outputInfo): ...
    def _RenderNode__processScriptOutput(self, outputInfo): ...
    def finalizeSetup(self, rect): ...
    def getCacheID(self): ...
    def getCleanupFiles(self): ...
    def getCommandLines(self): ...
    def getConvertFiles(self): ...
    def getCopyFiles(self): ...
    def getDataWindow(self): ...
    def getDisplayWindow(self): ...
    def getImageFiles(self): ...
    def getPackageString(self): ...
    def getPostCommands(self): ...
    def getPreCommands(self): ...
    def getRenderFinishedFilename(self): ...
    def getRendererString(self): ...
    def loadOutputsInMonitor(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import typing
from UI4.Widgets.StopButton import StopButton as StopButton
from typing import Set, Tuple

class ModalProcessInterruptWidget(PyQt5.QtWidgets.QFrame):
    def __init__(self, interruptCallback: typing.Callable, minWidth: int = ...) -> None: ...
    def _ModalProcessInterruptWidget__interrupt(self, *args, **kwargs): ...
    def closeEvent(self, e): ...
    def disableStopButton(self): ...
    def interrupted(self): ...
    def update(self, message, tick: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NavigationToolbar(PyQt5.QtWidgets.QFrame):
    _NavigationToolbar__pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, callback: Incomplete | None = ..., maxHistoryLength: int = ...) -> None: ...
    def _NavigationToolbar__backButtonClicked(self): ...
    def _NavigationToolbar__backButtonMenuCallback(self, action): ...
    def _NavigationToolbar__backButtonRightClicked(self): ...
    def _NavigationToolbar__clearHistory(self): ...
    def _NavigationToolbar__forwardButtonClicked(self): ...
    def _NavigationToolbar__forwardButtonMenuCallback(self, action): ...
    def _NavigationToolbar__forwardButtonRightClicked(self): ...
    def _NavigationToolbar__loadResources(self): ...
    def _NavigationToolbar__updateState(self): ...
    def clearFuture(self): ...
    def clearPast(self): ...
    def getCallback(self): ...
    def getCurrentEntry(self): ...
    def pushEntry(self, name, meta): ...
    def setCallback(self, callback): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class KeyboardShortcutLineEdit(PyQt5.QtWidgets.QLineEdit):
    def keyPressEvent(self, keyEvent: PyQt5.QtGui.QKeyEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class TempColorWidget(TempColorWidgetBase, PyQt5.QtWidgets.QWidget):
    resetSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, orientation) -> None: ...
    def _getCentralRect(self): ...
    def _updateDisplay(self): ...
    def _valueChanged(self, color, final): ...
    def enterEvent(self, ev): ...
    def isPreselectionActive(self): ...
    def leaveEvent(self, ev): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintEvent(self, ev): ...
    def reset(self): ...
    def setContentsMargins(self, left, top, right, bottom): ...
    def sizePolicy(self): ...

class TempColorWidgetBase:
    def __init__(self, orientation) -> None: ...
    def _TempColorWidgetBase__colorToWindowPos(self, rgbColor): ...
    def _TempColorWidgetBase__windowPosToColor(self, spotCenterQt, previousRgbColor): ...
    def _doDrag(self, x, y): ...
    def _doPaint(self, p): ...
    def _endDrag(self, x, y): ...
    def _getCentralRect(self): ...
    def _isInDrag(self): ...
    def _updateDisplay(self): ...
    def _valueChanged(self, value, final): ...
    def getLocked(self): ...
    def getRGB(self): ...
    def isPreselectionActive(self): ...
    def minimumSizeHint(self): ...
    def setLocked(self, isLocked): ...
    def setRGB(self, color): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import UI4.Widgets.SortablePanel
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class ArraySliceProxyPolicy:
    def __init__(self, policy, sliceStart, sliceEnd, overrideHints: Incomplete | None = ...) -> None: ...
    def getArrayChild(self, index): ...
    def getArraySize(self): ...
    def getOpenStateKey(self): ...
    def getOverrideHints(self): ...
    def getPolicy(self): ...
    def getSliceEnd(self): ...
    def getSliceSize(self): ...
    def getSliceStart(self): ...
    def getWidgetHints(self): ...
    def shouldDisplayState(self): ...
    def updateSlice(self, sliceStart, sliceEnd): ...
    def __eq__(self, other) -> bool: ...
    def __getattr__(self, name): ...
    def __lt__(self, other) -> bool: ...
    def __ne__(self, other) -> bool: ...

class DynamicArrayFormWidget(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def buildAddMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    def on_newEntryAction_triggered(self): ...
    def panelDeleted(self, index: int): ...
    def panelReordered(self, oldIndex: int, newIndex: int): ...
    def updatePanels(self): ...

class DynamicArrayPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, policy, factory) -> None: ...
    def getPolicy(self): ...
    def setPolicy(self, policy): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyUtilModule.KatanaFile as KatanaFile
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def BrowseForLiveGroup(assetId: str = ...): ...
def CanVersionUpAndSave(): ...
def CheckForUnsavedChanges(dialogTitle: str, actionDescription: str) -> bool: ...
def ExportSelection(): ...
def Import(): ...
def ImportLiveGroup(): ...
def New(): ...
def Open(filename: Incomplete | None = ...): ...
def Revert(): ...
def Save(checkForModifiedLiveGroups: bool = ...) -> bool: ...
def SaveAs(checkForModifiedLiveGroups: bool = ...) -> bool: ...
def ShowLoadLiveGroupDialog(filenameOrAssetID: str = ..., title: str = ...) -> str: ...
def VersionUpAndSave(checkForModifiedLiveGroups: bool = ...) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import Utils as Utils
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from typing import Set, Tuple

class BandSelectionLayer(RectangleLayer):
    def __init__(self, clickPoint, inclusiveDrag, *args, **kwargs) -> None: ...
    def _BandSelectionLayer__cancelBandSelectMode(self): ...
    def _BandSelectionLayer__cleanUp(self): ...
    def _BandSelectionLayer__finishBandSelectMode(self): ...
    def _BandSelectionLayer__nodeDeleteHandler(self, eventType, eventID, **kwargs): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setLayerStack(self, stack): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import ViewerAPI as ViewerAPI
from typing import Set, Tuple

def GetViewports(viewerDelegate): ...
def PopupMenuUnderWidget(menu, widget): ...
def SetOptionOnAllMonitorLayers(name, value, delegate): ...
def SetOptionOnMonitorLayer(name, value, viewport): ...
def TruncateText(text, numChars): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import Utils as Utils
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FaceSelectionManager:
    sharedInstance: ClassVar[None] = ...
    def __init__(self) -> None: ...
    def getSelectedFaces(self, path: str) -> list: ...
    def getSelectedPathsAndFaces(self): ...
    def setSelectedPathsAndFaces(self, selectedPathsAndFaces: list, sender: Incomplete | None = ...): ...

def convertFaceSetToString(faceSet) -> str: ...
def createFaceSetFromString(faceSetStr: str) -> set: ...
def getFaceSelectionManager() -> FaceSelectionManager: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import _io
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

def AttrDump(output: _io.TextIOWrapper = ..., node: typing.Optional[NodegraphAPI.Node] = ..., mode: str = ..., sample: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import LookFileBakeAPI as LookFileBakeAPI
import PyFnGeolibProducers
import typing
from PyFnGeolibProducers import GeometryProducer as GeometryProducer
from _typeshed import Incomplete
from typing import Set, Tuple

_CelMatchAttrName: str
_formatVersionNames: dict
_formatVersions: dict
_inBakeState: bool
g_typeToAttrDict: dict

class DummyProducer:
    def getAttribute(self, name): ...
    def getAttributeNames(self): ...
    def getFirstChild(self): ...
    def getName(self): ...
    def getType(self): ...

class LocationIntervalEvictor:
    def __init__(self, interval, configVarName: Incomplete | None = ...) -> None: ...
    def advanceAndEvict(self, producer: PyFnGeolibProducers.GeometryProducer): ...
    def __bool__(self) -> bool: ...

class LookFileBakeException(RuntimeError): ...

def AttrEqual(attrA, attrB): ...
def BuildCollectionsInfoDict(rootProducer): ...
def BuildFullMaterialTree(rootProducer, progressCallback: typing.Optional[typing.Callable] = ...): ...
def BuildSelectedMaterialTree(rootProducer, rootPath, progressCallback: typing.Optional[typing.Callable] = ...): ...
def ConsolidateOverrides(outputDicts: typing.Sequence[dict], progressCallback: typing.Optional[typing.Callable] = ...) -> dict: ...
def ConstraintListDiff(producerA, producerB, rootLocation): ...
def CreateLookFileDirectory(dirPath: str): ...
def DeepAttrDiff(attrA, attrB, outputDict, attrPath: str = ...): ...
def GetBakeState(): ...
def LightListDiff(producerA, producerB, rootLocation): ...
def ScenegraphHierarchyDiff(producerA, producerB, materialsProducer, progressCallback: typing.Optional[typing.Callable] = ..., collectionInfo: Incomplete | None = ..., evictor: Incomplete | None = ...): ...
def ScenegraphImmediateChildDiff(producerA, producerB, materialsProducer, progressCallback: typing.Optional[typing.Callable] = ...): ...
def ScenegraphLocationDiff(producerA, producerB, materialsProducer, materialDict): ...
def SetBakeState(state): ...
def SetLog(log): ...
def WriteLookFile(filePath, outputDictList, materialDict, sharedOverridesDict: Incomplete | None = ..., rootOverrideDict: Incomplete | None = ..., sourceFile: Incomplete | None = ..., sourceAsset: Incomplete | None = ..., format: int = ...): ...
def _ScenegraphHierarchyDiff(producerA, producerB, materialsProducer, locationName, outputDict, materialDict, progressCallback: typing.Optional[typing.Callable] = ..., collectionInfo: Incomplete | None = ..., evictor: Incomplete | None = ...): ...
def _WalkMaterialLocation(producer: PyFnGeolibProducers.GeometryProducer, materialDict, progressCallback: typing.Callable): ...
def _WalkMaterialLocations(parentProducer, materialDict, progressCallback: typing.Optional[typing.Callable] = ..., includeTopLevel: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
from typing import Set, Tuple

class StructuredPort:
    def __init__(self, node: NodegraphAPI.Node, port: NodegraphAPI.Port, name, parent) -> None: ...
    def getBarCode(self): ...
    def getChildren(self): ...
    def getChildrenIter(self): ...
    def getFullName(self): ...
    def getName(self): ...
    def getParent(self): ...
    def getRawPort(self): ...
    def getType(self): ...

class _NodePortQuery:
    def __init__(self, node: NodegraphAPI.Node, isInput) -> None: ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getPort(self, name): ...
    def getPorts(self): ...

def GetStructuredInputPorts(node: NodegraphAPI.Node): ...
def GetStructuredOutputPorts(node: NodegraphAPI.Node): ...
def GetStructuredPort(port: NodegraphAPI.Port): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import AutoPosition as AutoPosition, CustomColors as CustomColors, Manifest as Manifest, NodeShapeAttrUtil as NodeShapeAttrUtil
from DrawingModule.AutoPosition import AutoPositionNodes as AutoPositionNodes, FitBackdropNodeAroundNodes as FitBackdropNodeAroundNodes, FitStickyAroundNodes as FitStickyAroundNodes
from DrawingModule.CustomColors import CopyNodeColorToLinkColor as CopyNodeColorToLinkColor, GetCustomNodeColor as GetCustomNodeColor, HasCustomNodeColor as HasCustomNodeColor, RemoveCustomNodeColor as RemoveCustomNodeColor, SetCustomNodeColor as SetCustomNodeColor
from drawing_cmodule import GetFontFile as GetFontFile, angleVector2D as angleVector2D, boundBoxBox as boundBoxBox, insideVector2DBox as insideVector2DBox, intersectBoxBox as intersectBoxBox, intersectLineBox as intersectLineBox, intersectLines as intersectLines, lengthVector2D as lengthVector2D, nodeShape_clearAllHiddenPortLinks as nodeShape_clearAllHiddenPortLinks, nodeShape_setPortLinkHidden as nodeShape_setPortLinkHidden, nodeWorld_addNode as nodeWorld_addNode, nodeWorld_draw as nodeWorld_draw, nodeWorld_drawFloatingLink as nodeWorld_drawFloatingLink, nodeWorld_drawPreselect as nodeWorld_drawPreselect, nodeWorld_drawSelectedLink as nodeWorld_drawSelectedLink, nodeWorld_drawSelectedPort as nodeWorld_drawSelectedPort, nodeWorld_drawShadow as nodeWorld_drawShadow, nodeWorld_drawText as nodeWorld_drawText, nodeWorld_findGroupNodeOfClick as nodeWorld_findGroupNodeOfClick, nodeWorld_flowText as nodeWorld_flowText, nodeWorld_getBounds as nodeWorld_getBounds, nodeWorld_getBoundsOfListOfNodes as nodeWorld_getBoundsOfListOfNodes, nodeWorld_getChildBounds as nodeWorld_getChildBounds, nodeWorld_getFloatingOffset as nodeWorld_getFloatingOffset, nodeWorld_getGroupNodeRelativeAndAbsoluteChildScales as nodeWorld_getGroupNodeRelativeAndAbsoluteChildScales, nodeWorld_getLinkEndPoints as nodeWorld_getLinkEndPoints, nodeWorld_getNodeDehilitingMode as nodeWorld_getNodeDehilitingMode, nodeWorld_getPortPosition as nodeWorld_getPortPosition, nodeWorld_getShapeAttrAsNumber as nodeWorld_getShapeAttrAsNumber, nodeWorld_getShapeAttrAsString as nodeWorld_getShapeAttrAsString, nodeWorld_hitTestBox as nodeWorld_hitTestBox, nodeWorld_hitTestInset as nodeWorld_hitTestInset, nodeWorld_hitTestNode as nodeWorld_hitTestNode, nodeWorld_hitTestPoint as nodeWorld_hitTestPoint, nodeWorld_isLargePortAreaEnabled as nodeWorld_isLargePortAreaEnabled, nodeWorld_loadSceneIntoNodegraphSvgManager as nodeWorld_loadSceneIntoNodegraphSvgManager, nodeWorld_mapFromWorldPositionToCurrentGroupWorldPosition as nodeWorld_mapFromWorldPositionToCurrentGroupWorldPosition, nodeWorld_measureText as nodeWorld_measureText, nodeWorld_moveNode as nodeWorld_moveNode, nodeWorld_refreshAllViewMaskLinkColors as nodeWorld_refreshAllViewMaskLinkColors, nodeWorld_refreshAllViewMasks as nodeWorld_refreshAllViewMasks, nodeWorld_refreshNodeViewMaskFlags as nodeWorld_refreshNodeViewMaskFlags, nodeWorld_removeNode as nodeWorld_removeNode, nodeWorld_sceneIsLoadedIntoNodegraphSvgManager as nodeWorld_sceneIsLoadedIntoNodegraphSvgManager, nodeWorld_setExpressionLinksEnabled as nodeWorld_setExpressionLinksEnabled, nodeWorld_setFloatingOffset as nodeWorld_setFloatingOffset, nodeWorld_setLargePortAreaEnabled as nodeWorld_setLargePortAreaEnabled, nodeWorld_setLargePortAreaIncludeTypes as nodeWorld_setLargePortAreaIncludeTypes, nodeWorld_setLowContrastLookEnabled as nodeWorld_setLowContrastLookEnabled, nodeWorld_setNodeActive as nodeWorld_setNodeActive, nodeWorld_setNodeDehilitingEnabled as nodeWorld_setNodeDehilitingEnabled, nodeWorld_setNodeDehilitingMode as nodeWorld_setNodeDehilitingMode, nodeWorld_setNodeState as nodeWorld_setNodeState, nodeWorld_setNodeThumbnail as nodeWorld_setNodeThumbnail, nodeWorld_setNodeThumbnailEnabled as nodeWorld_setNodeThumbnailEnabled, nodeWorld_setParent as nodeWorld_setParent, nodeWorld_setShapeAttr as nodeWorld_setShapeAttr, nodeWorld_setShowNodeIcons as nodeWorld_setShowNodeIcons, nodeWorld_setViewMasksEnabled as nodeWorld_setViewMasksEnabled, nodeWorld_shouldLargePortAreaIncludeInputPorts as nodeWorld_shouldLargePortAreaIncludeInputPorts, nodeWorld_shouldLargePortAreaIncludeOutputPorts as nodeWorld_shouldLargePortAreaIncludeOutputPorts, nodeWorld_tranformPointToChildSpace as nodeWorld_tranformPointToChildSpace, nodeWorld_updateNodeHiliteTableWithIncomingNodes as nodeWorld_updateNodeHiliteTableWithIncomingNodes, normalizeVector2D as normalizeVector2D, scaleBoxVector2D as scaleBoxVector2D, translateBoxVector2D as translateBoxVector2D
from typing import Set, Tuple

NodeDehilightingModeConnected: int
NodeDehilightingModeContributing: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.KatanaColor as KatanaColor
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.KatanaColor
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from UI4.FormMaster.Editors.ColorArrayFormWidget import ColorArrayFormWidget as ColorArrayFormWidget
from typing import ClassVar, Set, Tuple

class ArraySliceProxyPolicy:
    def __init__(self, policy, sliceStart, sliceEnd) -> None: ...
    def getArrayChild(self, index): ...
    def getArraySize(self): ...
    def getExtraHints(self): ...
    def getOpenStateKey(self): ...
    def getWidgetHints(self): ...
    def __getattr__(self, name): ...

class BalancedArrayFormWidget(ColorArrayFormWidget):
    class ColorWidget(UI4.FormMaster.Editors.KatanaColor.KatanaColorFormWidget):
        class SetValuePolicyProxy(QT4FormWidgets.ValuePolicy.ValuePolicyProxy):
            colorChange: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
            def __init__(self, policy, parentWidget, index) -> None: ...
            def setValue(self, value, final: bool = ...): ...
        colorChange: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def _popdownCreated(self, popdown): ...
        def execColorPicker(self): ...
        def setColor_RGBA(self, color, final: bool = ...): ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _BalancedArrayFormWidget__balanceFrom(self, index): ...
    def _BalancedArrayFormWidget__checkboxStateChanged(self, state): ...
    def _BalancedArrayFormWidget__colorChange(self, index): ...
    def _buildColorWidget(self, parent, policy, index): ...
    def _buildControlWidget(self, layout): ...

class ColorArrayFormWidget(GroupFormWidget):
    def _buildColorWidget(self, parent, policy, index): ...
    def _popdownCreated(self, popdown): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import GeoAPI as GeoAPI
import PluginSystemAPI as PluginSystemAPI
from . import ArgsFileUtil as ArgsFileUtil, CelUtil as CelUtil, GenericAppenderUtil as GenericAppenderUtil, HintDictUtil as HintDictUtil, LookFileUtil as LookFileUtil, Matrix as Matrix
from GeoAPI.Util.CelUtil import CollectPathsFromCELStatement as CollectPathsFromCELStatement
from PyFnGeolibProducers import BinaryAttrWriter as BinaryAttrWriter, ClearLookFileCache as ClearLookFileCache, GetLookFilePassMaterials as GetLookFilePassMaterials
from typing import Set, Tuple

def __FlushCaches(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from _typeshed import Incomplete
from typing import Set, Tuple

class CallbackButtonFormWidget(BaseValueFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _CallbackButtonFormWidget__refreshButton(self, button: PyQt5.QtWidgets.QPushButton, text: str, iconFilename: Incomplete | None = ...): ...
    def _buildControlWidget(self, layout: PyQt5.QtWidgets.QLayout) -> PyQt5.QtWidgets.QWidget: ...
    def _lockChanged(self, state: bool): ...
    def _updateControlWidget(self): ...
    def on_button_clicked(self): ...
    def setLabelWidth(self, width: int): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
from typing import Set, Tuple

class UndoEntry:
    def __init__(self, name) -> None: ...
    def getName(self): ...
    def isValid(self) -> bool: ...
    def redo(self): ...
    def setName(self, name): ...
    def undo(self): ...

class _UndoGroupEntry(UndoEntry):
    def __init__(self, name: str = ...) -> None: ...
    def _UndoGroupEntry__nonzero(self): ...
    def addEntry(self, entry: UndoEntry): ...
    def clear(self): ...
    def getName(self) -> str: ...
    def isValid(self): ...
    def redo(self): ...
    def undo(self): ...
    def __len__(self) -> int: ...

def AddEntry(entry: UndoEntry): ...
def AddEntrySync(entry): ...
def Clear(): ...
def CloseGroup(discard: bool = ...): ...
def CloseGroupSync(discard: bool = ...): ...
def DisableCapture(): ...
def DisableCaptureSync(): ...
def EnableCapture(): ...
def EnableCaptureSync(): ...
def GetLastUndoName() -> str: ...
def GetNextRedoName() -> str: ...
def GetRedoNames() -> list[str]: ...
def GetRedoSize() -> int: ...
def GetUndoNames() -> list[str]: ...
def GetUndoSize() -> int: ...
def IsInsideGroup() -> bool: ...
def IsInsideGroupSync(): ...
def IsUndoEnabled() -> bool: ...
def IsUndoEnabledSync(): ...
def IsUndoInProgress(): ...
def NoCaptureContext(): ...
def OpenGroup(groupName: str = ...): ...
def OpenGroupSync(groupName): ...
def Redo(): ...
def RegisterCallback(callback): ...
def RenameTopGroupSync(name): ...
def Undo(): ...
def UndoInitAsync(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from Callbacks.Callbacks import Callbacks as Callbacks, DeclareCallbackType as DeclareCallbackType, ExecuteCallbacksForType as ExecuteCallbacksForType
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4Widgets.PopdownLabel import PopdownLabel
from typing import Set, Tuple

class FCurveSnapSettingsMenu(PopdownLabel):
    def __init__(self, graphWidget, *args) -> None: ...
    def _FCurveSnapSettingsMenu__buildSettings(self, xInc, yInc): ...
    def buildMenu(self, menu): ...
    def updateState(self): ...

class SnapSettingsAction(PyQt5.QtWidgets.QAction):
    def __init__(self, settings, graphWidget, *args) -> None: ...
    def _SnapSettingsAction__activatedCB(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.KatanaFile as KatanaFile
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import typing
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

_AutoSaveIntervalSeconds: int
_LastUndoEventTime: float
_MinimumSecondsBetweenUndoEvents: float
_MinutesBeforeAutoSave: int
_MinutesBeforeAutoSavePrefKey: str
_NumberOfActionsBeforeAutoSave: int
_NumberOfActionsBeforeAutoSavePrefKey: str
_autoSaveTimer: None

def Initialize(): ...
def _AutoSave(): ...
def __on_autosaveTimer_timeout(): ...
def __on_pref_changed(eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
def __on_undoStack_change(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import Utils as Utils
from NodegraphAPI_cmodule import Predefined as Predefined
from typing import Set, Tuple

def AddNodeFlavor(nodeType, flavor): ...
def ClearFlavorNodes(flavor): ...
def GetAllFlavors(): ...
def GetFlavorNodes(flavor, filterExists: bool = ...): ...
def GetNodeFlavors(nodeType): ...
def NodeMatchesFlavors(nodeType, flavors, ignoreFlavors): ...
def RemoveNodeFlavor(nodeType, flavor): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import UI4.Widgets.StopButton
import Utils as Utils
from UI4.Widgets.StopButton import SimpleStopWidget as SimpleStopWidget
from typing import Set, Tuple

class GeolibProcessingStateWidget(UI4.Widgets.StopButton.SimpleStopWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _GeolibProcessingStateWidget__stateChangedCallback(self, eventType: str | None, eventId, state: bool = ...): ...
    def _GeolibProcessingStateWidget__timerTick(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyFnAttribute as FnAttribute
import UI4.Widgets.MonitorLayer.Utils as MonitorLayerUtils
import Nodes2DAPI as Nodes2DAPI
import PyFnAttribute
import Utils as Utils
from PyUtilModule.VirtualKatana import RenderGlobals as RenderGlobals, RenderManager as RenderManager
from _typeshed import Incomplete
from typing import Set, Tuple

DISPLAY_WHILE_MANIPULATING: bool
IGNORE_ALPHA: bool
MONITOR_LAYER_DEFAULT: bool

class MonitorLayer:
    viewportFollowedByLiveRender: Incomplete
    def __init__(self, tab) -> None: ...
    def _MonitorLayer__cameraMatchesRenderCamera(self, viewport): ...
    def _MonitorLayer__getCatalogItemRenderCamera(self) -> tuple[int, str]: ...
    def _MonitorLayer__manipulationStarts(self): ...
    def _MonitorLayer__manipulationStops(self): ...
    def _MonitorLayer__on_catalog_clientSlotUpdate(self, eventType: str | None, eventID: object): ...
    def _MonitorLayer__on_catalog_itemDelete(self, eventType: str | None, eventID: object, item: CatalogAPI.CatalogItem): ...
    def _MonitorLayer__on_catalog_itemImageRegionUpdate(self, eventType: str | None, eventID: object, item: CatalogAPI.CatalogItem, layerview: Incomplete | None = ..., updateRects: Incomplete | None = ...): ...
    def _MonitorLayer__on_catalog_itemRenderCameraUpdate(self, eventType: str | None, eventID: object, item: CatalogAPI.CatalogItem): ...
    def _MonitorLayer__on_catalog_rebuild(self, eventType, eventID): ...
    def _MonitorLayer__registerMonitorLayerEventHandlers(self): ...
    def _MonitorLayer__resetMonitorLayer(self): ...
    def _MonitorLayer__setMonitorLayerOption(self, viewport, name, value: PyFnAttribute.IntAttribute = ...): ...
    def _MonitorLayer__setMonitorLayerOptionForAllViewports(self, name: str, value: PyFnAttribute.IntAttribute = ...): ...
    def _MonitorLayer__setUp(self): ...
    def _MonitorLayer__tearDown(self): ...
    def _MonitorLayer__unregisterLayerEventHandlers(self): ...
    def matchFirstViewportCameraWithCatalogItemRenderCamera(self): ...
    def setDisplayWhileManipulating(self, displayWhileManipulating: bool): ...
    def setEnabled(self, enabled: bool): ...
    def setIgnoresAlpha(self, value): ...
    def setMonitorLayerVisible(self, visible: bool): ...
    def setupCatalogItem(self): ...
    def toggleEnabled(self): ...
    def toggleIgnoresAlpha(self): ...
    def toggledisplayWhileManipulating(self): ...
    def update(self): ...
    def updateImageVisibilityForViewport(self, viewport, visible: bool = ...): ...
    def updateMonitorLayerIgnoresAlpha(self): ...
    def updateSelection(self): ...
    @property
    def displayWhileManipulating(self): ...
    @property
    def enabled(self): ...
    @property
    def monitorLayerIgnoresAlpha(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class HighlightWidget(PyQt5.QtWidgets.QRubberBand):
    def __init__(self, widget: PyQt5.QtWidgets.QWidget) -> None: ...
    def _HighlightWidget__on_highlightWidgetTimer_timeout(self): ...
    def mouseMoveEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.MenuUtils as MenuUtils
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FDisclosureTriangle as FDisclosureTriangle
from QT4FormWidgets.FixableBoxLayout import FixableBoxLayout as FixableBoxLayout
from QT4FormWidgets.InputWidgets import InputLineEdit as InputLineEdit, InputTextEdit as InputTextEdit
from QT4FormWidgets.NumberFormWidget import EvalLocalMath as EvalLocalMath
from typing import Set, Tuple

class ArrayItemEntry(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent) -> None: ...
    def _ArrayItemEntry__on_entry_dragStarted(self): ...
    def _ArrayItemEntry__on_entry_lostFocus(self): ...
    def _ArrayItemEntry__on_exprTriangle_expanded(self, item, state): ...
    def _ArrayItemEntry__on_expr_lostFocus(self): ...
    def contextMenuEvent(self, event): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def isLocked(self): ...
    def mousePressEvent(self, event): ...
    def policyChanged(self, event): ...
    def setLocked(self, state): ...
    def setPolicy(self, policy): ...

def DarkPalette(palette): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.ExternalEditorDialog as ExternalEditorDialog
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from QT4FormWidgets.FormWidget import FormWidget as FormWidget
from QT4FormWidgets.InputWidgets import HelpButton as HelpButton, HelpFWidget as HelpFWidget, InputComboBox as InputComboBox, InputLineEdit as InputLineEdit, InputTextEdit as InputTextEdit
from QT4FormWidgets.ValuePolicy import AbstractValuePolicy as AbstractValuePolicy, ValuePolicyEvent as ValuePolicyEvent, ValuePolicyProxy as ValuePolicyProxy
from QT4FormWidgets.WideEditDialog import WideEditDialog as WideEditDialog
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from typing import ClassVar, Set, Tuple

class BaseValueFormWidget(FormWidget):
    _Pixmaps: ClassVar[dict] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _BaseValueFormWidget__autoKeyClicked(self): ...
    def _BaseValueFormWidget__curveShowClicked(self): ...
    def _BaseValueFormWidget__loadPixmaps(self): ...
    def _BaseValueFormWidget__triangleClicked(self, item, state): ...
    def _BaseValueFormWidget__updateCurveAndExpression(self): ...
    def _BaseValueFormWidget__updateExpr(self): ...
    def _lockChanged(self, state): ...
    def _popdownCreated(self, popdown): ...
    def _popupMenuCreated(self, menu): ...
    def _thaw(self): ...
    def _updateControlWidget(self): ...
    def getMaximumLeftControlWidgetWidth(self): ...
    def setVisible(self, vis, checkVisOps: bool = ...): ...
    def showExternalEditor(self): ...
    def showWideEditor(self): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import Nodes2DAPI as Nodes2DAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel
from UI4.Widgets.SortablePanel import ParameterSortablePanel as ParameterSortablePanel, ParameterSortablePanelFormWidget as ParameterSortablePanelFormWidget
from typing import Set, Tuple

class GradientInputPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, factory) -> None: ...
    def _GradientInputPanel__valueChangedCallback(self): ...
    def getName(self): ...

class LinearGradientGroupFormWidget(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _getPanelForPolicy(self, vp): ...
    def addPoint(self): ...
    def buildAddMenu(self, menu): ...

class SuperGradientFormWidget(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _getPanelForPolicy(self, vp): ...
    def addPoint(self): ...
    def buildAddMenu(self, menu): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class ChildProcess:
    def __init__(self, childProc) -> None: ...
    def kill(self, sig): ...
    def poll(self): ...
    def read(self, n): ...
    def write(self, str): ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import Nodes3DAPI.Node3D as Node3D
import Nodes2DAPI as Nodes2DAPI
import PyFnGeolibProducers
import RenderingAPI as RenderingAPI
import Nodes3DAPI.RenderingUtil as RenderingUtil
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def CancelAllRenders(waitOnCompletion: bool = ..., predicate: Incomplete | None = ...): ...
def CancelRender(mainSequenceID: int, waitOnCompletion: bool = ..., predicate: Incomplete | None = ...): ...
def GetRenderCommandLine(renderer: str, renderMethodType: str, renderMethodName: str, renderTime: float, geolib3OpTreeFilename: str, frameRanges: str, useID: bool, mainSequenceID: Incomplete | None = ..., debugOutputFilename: Incomplete | None = ..., expandProcedural: bool = ..., renderSettings: Incomplete | None = ..., enableRuntimeProfiling: bool = ..., **kwargs) -> str: ...
def RenderNode3D(producer: PyFnGeolibProducers.GeometryProducer, sampleRate: tuple[float, ...], regionOfInterest, renderNodeName: str, renderTime: float, mainSequenceID: int, useID: bool, geolib3OpTreeFilename: str, frameRanges: str, renderMethodType: Incomplete | None = ..., renderMethodName: Incomplete | None = ..., registerRender: bool = ..., reportRenderMessages: bool = ..., debugOutputFilename: Incomplete | None = ..., expandProcedural: bool = ..., rendererOverride: Incomplete | None = ..., enableRuntimeProfiling: bool = ..., remoteRender: bool = ..., renderFarm: Incomplete | None = ...) -> None: ...
def SignalRender(mainSequenceID, signal): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

def __inputPortUpdate(eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import NodegraphAPI.RenderFilter
from typing import Set, Tuple

def GetActiveRenderFilterNodes() -> list[NodegraphAPI.RenderFilter.RenderFilterNode]: ...
def IsValidRenderFilterNode(node: NodegraphAPI.Node) -> bool: ...
def SetActiveRenderFilterNodes(nodes: list[NodegraphAPI.RenderFilter.RenderFilterNode]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from typing import ClassVar, Set, Tuple

class LightLinkItemDelegate(ParameterItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    MinimumColumnWidth: ClassVar[int] = ...
    _LightLinkItemDelegate__colors: ClassVar[None] = ...
    def _LightLinkItemDelegate__getBadgeColors(self, isEnabled: bool, isLocal: bool) -> tuple[QColor, QColor, QColor]: ...
    def _LightLinkItemDelegate__getBadgeDimensions(self, option: PyQt5.QtWidgets.QStyleOptionViewItem) -> None: ...
    def _LightLinkItemDelegate__getLightData(self, index: PyQt5.QtCore.QModelIndex): ...
    def getContentWidth(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> int: ...
    def paint(self, painter: PyQt5.QtGui.QPainter, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

class FnMatchHintsDelegate:
    def __init__(self, hints) -> None: ...
    def addWidgetHints(self, param, name, attrDict): ...

class SimpleDictHintsDelegate:
    def __init__(self, hints) -> None: ...
    def addWidgetHints(self, param, name, attrDict): ...

def RegisterAttributeHintsDelegate(delegate): ...
def RegisterHintsDelegate(nodeType, delegate): ...
def UpdateAttributeHintsWithDelegates(name, attrDict): ...
def UpdateHintsWithDelegates(nodeType, param, name, attrDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.DynamicTemplateGroup
from UI4.FormMaster.Editors.DynamicTemplateGroup import DynamicTemplateGroupFormWidget as DynamicTemplateGroupFormWidget
from UI4.FormMaster.Editors.ShadingNetworkPopupButton import ShadingNetworkPopupButton as ShadingNetworkPopupButton
from typing import ClassVar, Set, Tuple

class NetworkMaterialParameterEditFormWidget(UI4.FormMaster.Editors.DynamicTemplateGroup.DynamicTemplateGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _NetworkMaterialParameterEditFormWidget__addNode(self, groupName): ...
    def _NetworkMaterialParameterEditFormWidget__getMaterialAttr(self): ...
    def _NetworkMaterialParameterEditFormWidget__getNetworkAttr(self): ...
    def _NetworkMaterialParameterEditFormWidget__toggleNodeCallback(self, name): ...
    def _buildControlWidget(self, layout): ...
    def _childPanelsShouldAddWrench(self): ...
    def _menuAction(self, action): ...
    def buildAddMenu(self, menu): ...

class _NodeCheckboxLayer(QT4GLLayerStack.LayerStack.Layer):
    toggleNode: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, name, param) -> None: ...
    def _NodeCheckboxLayer__getMenu(self): ...
    def _NodeCheckboxLayer__toggleName(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.LiveGroup as LiveGroup
import UI4.FormMaster.NodeActionDelegate.NodeActionDelegate as NodeActionDelegate
import UI4.Util.NodeGraphTab as NodeGraphTab
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.FormMaster.NodeActionDelegate.BaseNodeActionDelegate import BaseNodeActionDelegate as BaseNodeActionDelegate
from _typeshed import Incomplete
from typing import Set, Tuple

class GroupActionDelegate(BaseNodeActionDelegate):
    class _ConvertToLiveGroupAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _ConvertToLiveGroupAction__triggered(self, checked): ...

    class _ShowUserParametersAtTopLevelAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _ShowUserParametersAtTopLevelAction__triggered(self, checked): ...

    class _ToggleGroupNodeAppearanceAction(PyQt5.QtWidgets.QAction):
        def __init__(self, parent, node: NodegraphAPI.Node) -> None: ...
        def _ToggleGroupNodeAppearanceAction__triggered(self, checked): ...
    def addToContextMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToWrenchMenu(self, menu, node: NodegraphAPI.Node, hints: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def begin_timing(context): ...
def end_timing(context): ...
def init_gpu_timing(name): ...
def render_timing_stats(layerStack): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import Set, Tuple

class AssetIdSaveWidget(AssetIdWidget):
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...

class AssetIdWidget(StringFormWidget):
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...
    def _AssetIdWidget__getRenderNodeFromEvent(self, event): ...
    def _AssetIdWidget__setupEventHandlers(self, active): ...
    def _AssetIdWidget__showExtendedInfo(self, infoDialog): ...
    def _AssetIdWidget__updatePluginWidget(self, *args, **kwargs): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _fillMenu(self, menu): ...
    def _filterValueText(self, text): ...
    def _freeze(self): ...
    def _helper(self): ...
    def _lockChanged(self, state): ...
    def _popupMenuCreated(self, menu): ...
    def _thaw(self): ...
    def _updateControlWidget(self): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...
    def getMenu(self): ...
    def valueChangedEvent(self, event): ...

class FileInputWidget(AssetIdWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class LiveGroupSourceWidget(AssetIdWidget):
    class PolicyWrapper(QT4FormWidgets.ValuePolicy.ValuePolicyProxy):
        def isLocked(self): ...
    def __init__(self, parent, policy, factory, forceFile: bool = ...) -> None: ...
    def isLocked(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from UI4.Tabs.ExampleProjectsTab.ExampleProjectsTab import ExampleProjectsTab as ExampleProjectsTab
from typing import Set, Tuple

PluginRegistry: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from typing import Set, Tuple

ActionText: dict
Continuous: int
Manual: int
Modes: tuple
Options: list
PenUp: int

def GetUpdateMode() -> int: ...
def IsDirty(): ...
def SetDirty(dirty): ...
def SetUpdateMode(updateMode: int): ...
def TriggerManualUpdate(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import AimConstraint as AimConstraint, BaseConstraint as BaseConstraint, BillboardConstraint as BillboardConstraint, CameraScreenWindowConstraint as CameraScreenWindowConstraint, ClippingConstraint as ClippingConstraint, ConstraintEdit as ConstraintEdit, ConstraintResolve as ConstraintResolve, DollyConstraint as DollyConstraint, FOVConstraint as FOVConstraint, OrientConstraint as OrientConstraint, ParentChildConstraint as ParentChildConstraint, PointConstraint as PointConstraint, ReflectionConstraint as ReflectionConstraint, ScaleConstraint as ScaleConstraint, ScreenCoordinateConstraint as ScreenCoordinateConstraint
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from UI4.Util.ScenegraphLocation import GetNodesCreatingSceneGraphLocations as GetNodesCreatingSceneGraphLocations
from typing import ClassVar, Set, Tuple

class MaterialAssignDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    _ValidItems: ClassVar[list] = ...
    _ValidNodes: ClassVar[list] = ...
    def _MaterialAssignDelegate__droppedNode(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialAssignDelegate__droppedScenegraphItem(self, targetNode, item): ...
    def _MaterialAssignDelegate__validNodeDrop(self, targetNode, event): ...
    def _MaterialAssignDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

def GetMissingOpenGlExtensions() -> list[str | None]: ...
def ShowErrorInitializingOpenGlDialog() -> bool: ...
def ShowExtensionErrorDialog(window, missingExtensions): ...
def ShowRemoteHostDialog(window, missingExtensions): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ConditionalHints as ConditionalHints, ScenegraphColumnDescription as ScenegraphColumnDescription, UserParametersDialogs as UserParametersDialogs
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class Histogram:
    def __init__(self, channels) -> None: ...
    def getChannel(self, name): ...
    def getChannels(self): ...
    def getCounts(self, index): ...
    def getMaxSize(self): ...

class HistogramChannel:
    def __init__(self, name, data, count: Incomplete | None = ..., size: Incomplete | None = ..., stats: Incomplete | None = ..., domain: Incomplete | None = ...) -> None: ...
    def getCount(self, index): ...
    def getData(self): ...
    def getDomain(self): ...
    def getDomainBelowFraction(self, fraction, ignoreZero: bool = ...): ...
    def getName(self): ...
    def getSize(self): ...
    def getStats(self): ...
    def getTotalCount(self): ...

class HistogramWidget(PyQt5.QtWidgets.QOpenGLWidget):
    _TextBorderSize: ClassVar[int] = ...
    setTraceLocationSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showTraceSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _HistogramWidget__drawAxes(self): ...
    def _HistogramWidget__drawHistogram(self): ...
    def _HistogramWidget__drawLabel(self): ...
    def _HistogramWidget__renderText(self, x, y, text, font, color): ...
    def getGlobalScale(self): ...
    def isChannelEnabled(self, channel): ...
    def mouseMoveEvent(self, ev): ...
    def mousePressEvent(self, ev): ...
    def mouseReleaseEvent(self, ev): ...
    def paintGL(self): ...
    def resizeGL(self, width, height): ...
    def setChannels(self, channels): ...
    def setGlobalScale(self, scale): ...
    def setHistogram(self, histogram): ...
    def setLabel(self, label): ...
    def setProbe(self, probePixelLoc): ...
    def setScale(self, scale): ...
    def setTraceLocation(self, x): ...
    def showTrace(self, isShown): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyResolutionTableFn as ResolutionTable
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from UI4.Widgets.ResolutionComboBox import ResolutionComboBox as ResolutionComboBox
from typing import Set, Tuple

class ResolutionFormWidget(BaseValueFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _ResolutionFormWidget__doChangedNumbers(self): ...
    def _ResolutionFormWidget__on_resolutionComboBox_itemChosen(self, text: str, meta: str): ...
    def _buildControlWidget(self, layout): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils as Utils
from typing import Set, Tuple

def DrawBucketOrderPreview(catalogItem, layerview, numTiles: int = ...): ...
def DrawBufferRectVisualization(catalogItem, layerview): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple

hexversion: int
version: str

class AllocationTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getAllocation(self) -> Any: ...
    def getNumVars(self, *args, **kwargs): ...
    def getVars(self) -> Any: ...
    def setAllocation(self, hwalloc) -> Any: ...
    def setVars(self, pyvars) -> Any: ...

class Baker:
    def __init__(self, *args, **kwargs) -> None: ...
    def bake(self, *args, **kwargs): ...
    def createEditableCopy(self, *args, **kwargs): ...
    def getConfig(self, *args, **kwargs): ...
    def getCubeSize(self, *args, **kwargs): ...
    def getFormat(self, *args, **kwargs): ...
    def getFormatExtensionByIndex(self, *args, **kwargs): ...
    def getFormatNameByIndex(self, *args, **kwargs): ...
    def getInputSpace(self, *args, **kwargs): ...
    def getLooks(self, *args, **kwargs): ...
    def getMetadata(self, *args, **kwargs): ...
    def getNumFormats(self, *args, **kwargs): ...
    def getShaperSize(self, *args, **kwargs): ...
    def getShaperSpace(self, *args, **kwargs): ...
    def getTargetSpace(self, *args, **kwargs): ...
    def getType(self, *args, **kwargs): ...
    def isEditable(self, *args, **kwargs): ...
    def setConfig(self, *args, **kwargs): ...
    def setCubeSize(self, *args, **kwargs): ...
    def setFormat(self, *args, **kwargs): ...
    def setInputSpace(self, *args, **kwargs): ...
    def setLooks(self, *args, **kwargs): ...
    def setMetadata(self, *args, **kwargs): ...
    def setShaperSize(self, *args, **kwargs): ...
    def setShaperSpace(self, *args, **kwargs): ...
    def setTargetSpace(self, *args, **kwargs): ...
    def setType(self, *args, **kwargs): ...

class CDLTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def CreateFromFile(self, *args, **kwargs): ...
    def equals(self, *args, **kwargs): ...
    def getDescription(self) -> Any: ...
    def getID(self) -> Any: ...
    def getOffset(self, *args, **kwargs): ...
    def getPower(self, *args, **kwargs): ...
    def getSOP(self, *args, **kwargs): ...
    def getSat(self, *args, **kwargs): ...
    def getSatLumaCoefs(self, pyData) -> Any: ...
    def getSlope(self, *args, **kwargs): ...
    def getXML(self, *args, **kwargs): ...
    def setDescription(self, str) -> Any: ...
    def setID(self, str) -> Any: ...
    def setOffset(self, pyData) -> Any: ...
    def setPower(self, pyData) -> Any: ...
    def setSOP(self, pyData) -> Any: ...
    def setSat(self, *args, **kwargs): ...
    def setSlope(self, pyData) -> Any: ...
    def setXML(self, *args, **kwargs): ...

class ColorSpace:
    def __init__(self, *args, **kwargs) -> None: ...
    def createEditableCopy(self, *args, **kwargs): ...
    def getAllocation(self, *args, **kwargs): ...
    def getAllocationVars(self, *args, **kwargs): ...
    def getBitDepth(self, *args, **kwargs): ...
    def getDescription(self, *args, **kwargs): ...
    def getEqualityGroup(self, *args, **kwargs): ...
    def getFamily(self, *args, **kwargs): ...
    def getName(self, *args, **kwargs): ...
    def getTransform(self, *args, **kwargs): ...
    def isData(self, *args, **kwargs): ...
    def isEditable(self, *args, **kwargs): ...
    def setAllocation(self, *args, **kwargs): ...
    def setAllocationVars(self, *args, **kwargs): ...
    def setBitDepth(self, *args, **kwargs): ...
    def setDescription(self, *args, **kwargs): ...
    def setEqualityGroup(self, *args, **kwargs): ...
    def setFamily(self, *args, **kwargs): ...
    def setIsData(self, *args, **kwargs): ...
    def setName(self, *args, **kwargs): ...
    def setTransform(self, *args, **kwargs): ...

class ColorSpaceTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getDst(self) -> Any: ...
    def getSrc(self) -> Any: ...
    def setDst(self, dstname) -> Any: ...
    def setSrc(self, srcname) -> Any: ...

class Config:
    def __init__(self, *args, **kwargs) -> None: ...
    @classmethod
    def CreateFromEnv(cls) -> Any: ...
    @classmethod
    def CreateFromFile(cls, filename) -> Any: ...
    @classmethod
    def CreateFromStream(cls, *args, **kwargs): ...
    def addColorSpace(self, pyColorSpace) -> Any: ...
    def addDisplay(self, *args, **kwargs): ...
    def addEnvironmentVar(self, *args, **kwargs): ...
    def addLook(self, pylook) -> Any: ...
    def clearColorSpaces(self) -> Any: ...
    def clearDisplays(self) -> Any: ...
    def clearEnvironmentVars(self, *args, **kwargs): ...
    def clearLook(self, *args, **kwargs): ...
    def clearLooks(self) -> Any: ...
    def createEditableCopy(self) -> Any: ...
    def getActiveDisplays(self) -> Any: ...
    def getActiveViews(self) -> Any: ...
    def getCacheID(self, *args, **kwargs): ...
    def getColorSpace(self, name) -> Any: ...
    def getColorSpaceNameByIndex(self, *args, **kwargs): ...
    def getColorSpaces(self) -> Any: ...
    def getCurrentContext(self) -> Any: ...
    def getDefaultDisplay(self) -> Any: ...
    def getDefaultLumaCoefs(self) -> Any: ...
    def getDefaultView(self, display) -> Any: ...
    def getDescription(self) -> Any: ...
    def getDisplay(self, *args, **kwargs): ...
    def getDisplayColorSpaceName(self, display, view) -> Any: ...
    def getDisplayLooks(self, display, view) -> Any: ...
    def getDisplays(self) -> Any: ...
    def getEnvironmentVarDefault(self, *args, **kwargs): ...
    def getEnvironmentVarDefaults(self, *args, **kwargs): ...
    def getEnvironmentVarNameByIndex(self, *args, **kwargs): ...
    def getIndexForColorSpace(self, *args, **kwargs): ...
    def getLook(self, str) -> Any: ...
    def getLookNameByIndex(self, *args, **kwargs): ...
    def getLooks(self) -> Any: ...
    def getNumColorSpaces(self, *args, **kwargs): ...
    def getNumDisplays(self, *args, **kwargs): ...
    def getNumEnvironmentVars(self, *args, **kwargs): ...
    def getNumLooks(self, *args, **kwargs): ...
    def getNumRoles(self, *args, **kwargs): ...
    def getNumViews(self, *args, **kwargs): ...
    def getProcessor(self, *args, **kwargs): ...
    def getRoleName(self, *args, **kwargs): ...
    def getSearchPath(self) -> Any: ...
    def getView(self, *args, **kwargs): ...
    def getViews(self, display) -> Any: ...
    def getWorkingDir(self) -> Any: ...
    def hasRole(self, *args, **kwargs): ...
    def isEditable(self) -> Any: ...
    def isStrictParsingEnabled(self, *args, **kwargs): ...
    def parseColorSpaceFromString(self, str) -> Any: ...
    def sanityCheck(self) -> Any: ...
    def serialize(self) -> Any: ...
    def setActiveDisplays(self, displays) -> Any: ...
    def setActiveViews(self, views) -> Any: ...
    def setDefaultLumaCoefs(self, pyCoef) -> Any: ...
    def setDescription(self, desc) -> Any: ...
    def setRole(self, role, csname) -> Any: ...
    def setSearchPath(self, path) -> Any: ...
    def setStrictParsingEnabled(self, *args, **kwargs): ...
    def setWorkingDir(self, path) -> Any: ...

class Context:
    def __init__(self, *args, **kwargs) -> None: ...
    def clearStringVars(self, *args, **kwargs): ...
    def createEditableCopy(self, *args, **kwargs): ...
    def getCacheID(self, *args, **kwargs): ...
    def getEnvironmentMode(self, *args, **kwargs): ...
    def getNumStringVars(self, *args, **kwargs): ...
    def getSearchPath(self, *args, **kwargs): ...
    def getStringVar(self, *args, **kwargs): ...
    def getStringVarNameByIndex(self, *args, **kwargs): ...
    def getWorkingDir(self, *args, **kwargs): ...
    def isEditable(self, *args, **kwargs): ...
    def loadEnvironment(self, *args, **kwargs): ...
    def resolveFileLocation(self, *args, **kwargs): ...
    def resolveStringVar(self, *args, **kwargs): ...
    def setEnvironmentMode(self, *args, **kwargs): ...
    def setSearchPath(self, *args, **kwargs): ...
    def setStringVar(self, *args, **kwargs): ...
    def setWorkingDir(self, *args, **kwargs): ...

class DisplayTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getChannelView(self) -> Any: ...
    def getColorTimingCC(self) -> Any: ...
    def getDisplay(self) -> Any: ...
    def getDisplayCC(self) -> Any: ...
    def getInputColorSpaceName(self) -> Any: ...
    def getLinearCC(self) -> Any: ...
    def getLooksOverride(self) -> Any: ...
    def getLooksOverrideEnabled(self) -> Any: ...
    def getView(self) -> Any: ...
    def setChannelView(self, pyCC) -> Any: ...
    def setColorTimingCC(self, pyCC) -> Any: ...
    def setDisplay(self, str) -> Any: ...
    def setDisplayCC(self, pyCC) -> Any: ...
    def setInputColorSpaceName(self, name) -> Any: ...
    def setLinearCC(self, pyCC) -> Any: ...
    def setLooksOverride(self, str) -> Any: ...
    def setLooksOverrideEnabled(self, enabled) -> Any: ...
    def setView(self, str) -> Any: ...

class Exception(Exception): ...

class ExceptionMissingFile(Exception): ...

class ExponentTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getValue(self) -> Any: ...
    def setValue(self) -> Any: ...

class FileTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getCCCId(self, *args, **kwargs): ...
    def getFormatExtensionByIndex(self, *args, **kwargs): ...
    def getFormatNameByIndex(self, *args, **kwargs): ...
    def getInterpolation(self, *args, **kwargs): ...
    def getNumFormats(self, *args, **kwargs): ...
    def getSrc(self, *args, **kwargs): ...
    def setCCCId(self, *args, **kwargs): ...
    def setInterpolation(self, *args, **kwargs): ...
    def setSrc(self, *args, **kwargs): ...

class GpuShaderDesc:
    def __init__(self, *args, **kwargs) -> None: ...
    def getCacheID(self, *args, **kwargs): ...
    def getFunctionName(self, *args, **kwargs): ...
    def getLanguage(self, *args, **kwargs): ...
    def getLut3DEdgeLen(self, *args, **kwargs): ...
    def setFunctionName(self, *args, **kwargs): ...
    def setLanguage(self, *args, **kwargs): ...
    def setLut3DEdgeLen(self, *args, **kwargs): ...

class GroupTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def clear(self, *args, **kwargs): ...
    def empty(self, *args, **kwargs): ...
    def getTransform(self, *args, **kwargs): ...
    def getTransforms(self, *args, **kwargs): ...
    def push_back(self, *args, **kwargs): ...
    def setTransforms(self, *args, **kwargs): ...
    def size(self, *args, **kwargs): ...

class LogTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getBase(self) -> Any: ...
    def setBase(self, base) -> Any: ...

class Look:
    def __init__(self, *args, **kwargs) -> None: ...
    def createEditableCopy(self, *args, **kwargs): ...
    def getDescription(self, *args, **kwargs): ...
    def getInverseTransform(self, *args, **kwargs): ...
    def getName(self, *args, **kwargs): ...
    def getProcessSpace(self, *args, **kwargs): ...
    def getTransform(self, *args, **kwargs): ...
    def isEditable(self, *args, **kwargs): ...
    def setDescription(self, *args, **kwargs): ...
    def setInverseTransform(self, *args, **kwargs): ...
    def setName(self, *args, **kwargs): ...
    def setProcessSpace(self, *args, **kwargs): ...
    def setTransform(self, *args, **kwargs): ...

class LookTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    def getDst(self, *args, **kwargs): ...
    def getLooks(self, *args, **kwargs): ...
    def getSrc(self, *args, **kwargs): ...
    def setDst(self, *args, **kwargs): ...
    def setLooks(self, *args, **kwargs): ...
    def setSrc(self, *args, **kwargs): ...

class MatrixTransform(Transform):
    def __init__(self, *args, **kwargs) -> None: ...
    @classmethod
    def Fit(cls, *args, **kwargs): ...
    @classmethod
    def Identity(cls, *args, **kwargs): ...
    @classmethod
    def Sat(cls, *args, **kwargs): ...
    @classmethod
    def Scale(cls, *args, **kwargs): ...
    @classmethod
    def View(cls, *args, **kwargs): ...
    def equals(self, *args, **kwargs): ...
    def getMatrix(self, *args, **kwargs): ...
    def getOffset(self, *args, **kwargs): ...
    def getValue(self, *args, **kwargs): ...
    def setMatrix(self, *args, **kwargs): ...
    def setOffset(self, *args, **kwargs): ...
    def setValue(self, *args, **kwargs): ...

class Processor:
    def __init__(self, *args, **kwargs) -> None: ...
    def applyRGB(self, pixeldata) -> Any: ...
    def applyRGBA(self, pixeldata) -> Any: ...
    def getCpuCacheID(self) -> Any: ...
    def getGpuLut3D(self, shaderDesc) -> Any: ...
    def getGpuLut3DCacheID(self, shaderDesc) -> Any: ...
    def getGpuShaderText(self, shaderDesc) -> Any: ...
    def getGpuShaderTextCacheID(self, shaderDesc) -> Any: ...
    def getMetadata(self) -> Any: ...
    def hasChannelCrosstalk(self) -> Any: ...
    def isNoOp(self) -> Any: ...

class ProcessorMetadata:
    def __init__(self, *args, **kwargs) -> None: ...
    def getFiles(self) -> Any: ...
    def getLooks(self) -> Any: ...

class Transform:
    def __init__(self, *args, **kwargs) -> None: ...
    def createEditableCopy(self, *args, **kwargs): ...
    def getDirection(self, *args, **kwargs): ...
    def isEditable(self, *args, **kwargs): ...
    def setDirection(self, *args, **kwargs): ...

def ClearAllCaches(*args, **kwargs): ...
def GetCurrentConfig(*args, **kwargs): ...
def GetLoggingLevel(*args, **kwargs): ...
def SetCurrentConfig(*args, **kwargs): ...
def SetLoggingLevel(*args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class FormWidgetLabel(PyQt5.QtWidgets.QLabel):
    def __init__(self, text: str, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def FormatByteSize(size: int) -> str: ...
    def _FormWidgetLabel__updateToolTip(self): ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def event(self, event: PyQt5.QtCore.QEvent) -> bool: ...
    def getBuddy(self): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def setColor(self, color: PyQt5.QtGui.QColor): ...
    def setText(self, text: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import PyUtilModule.FarmAPI as FarmAPI
import PyUtilModule.RenderManager.InteractiveRenderDelegateManager as InteractiveRenderDelegateManager
import PyUtilModule.NodeDebugOutput as NodeDebugOutput
import UI4.Util.NodeErrors as NodeErrors
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
import RenderingAPI as RenderingAPI
import Nodes3DAPI.ScenegraphMask as ScenegraphMask
import UI4 as UI4
import Utils as Utils
import logging
import typing
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Util.ClientManager import ClientManager as ClientManager
from typing import ClassVar, Set, Tuple

class PreviousRenderCommand:
    callback: ClassVar[None] = ...
    @staticmethod
    def isSet(): ...
    @staticmethod
    def render(): ...
    @staticmethod
    def reset(): ...
    @staticmethod
    def set(function, node: NodegraphAPI.Node, renderMethodKey, renderMethodName, label): ...

class __RenderMenuClientManager(ClientManager):
    def __init__(self, node: NodegraphAPI.Node, callback: typing.Callable) -> None: ...
    def _RenderMenuClientManager__addOrUpdateLocationCallback(self, event, key): ...

def AddRenderItemsToMenu(menu, node: NodegraphAPI.Node, port: NodegraphAPI.Port, log: logging.Logger = ..., addTop: bool = ..., addBottom: bool = ...): ...
def GetFirstLiveRenderMethodNameAndText() -> None | None: ...
def GetFirstPreviewRenderMethodNameAndText() -> None | None: ...
def SetPreviousRenderCommand(renderMethodName: str, node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.SceneGraphView.TreeWidgetItems
import Utils as Utils
from PyUtilModule.VirtualKatana import Widgets as Widgets
from UI4.Widgets.SceneGraphView.SceneGraphHandle import SceneGraphHandle as SceneGraphHandle
from UI4.Widgets.SceneGraphView.TreeWidgetItems import AttributeDataTreeWidgetItem as AttributeDataTreeWidgetItem
from typing import ClassVar, Set, Tuple

class AltErrorMessageItem(MessageItem):
    AttributeName: ClassVar[str] = ...
    LocationType: ClassVar[str] = ...

class CollectionItem(SceneGraphAttributeDataItem):
    AttributeName: ClassVar[str] = ...
    LocationType: ClassVar[str] = ...
    def __init__(self, parent, handle, topLevelHandle) -> None: ...
    @classmethod
    def ConfigureDrag(cls, draggedItems, dragObject): ...
    @classmethod
    def CreateContextMenu(cls, clickedItem, selectedItems): ...
    def _CollectionItem__getCollectionPath(self): ...
    def getCollectionInfo(self): ...
    def setCollectionInfo(self, collectionName, celStatement, collectionRoot): ...
    def updateChildIndicator(self): ...
    def updateDisplayData(self): ...

class CollectionsRootItem(SceneGraphAttributeDataItem):
    AttributeName: ClassVar[str] = ...
    LocationType: ClassVar[str] = ...
    def __init__(self, parent, handle, topLevelHandle) -> None: ...
    @classmethod
    def ConfigureDrag(cls, draggedItems, dragObject): ...
    def updateChildIndicator(self): ...
    def updateDisplayData(self): ...

class ErrorMessageItem(MessageItem):
    AttributeName: ClassVar[str] = ...
    LocationType: ClassVar[str] = ...

class MessageItem(SceneGraphAttributeDataItem):
    AttributeName: ClassVar[None] = ...
    LocationType: ClassVar[None] = ...
    StateChangedCallback: ClassVar[None] = ...
    _MessageItemWeakRefs: ClassVar[None] = ...
    def __init__(self, parent, handle, topLevelHandle) -> None: ...
    @classmethod
    def GetMessageItemWeakRefs(cls): ...
    @classmethod
    def SetStateChangedCallback(cls, callback): ...
    @classmethod
    def _MessageItem__callStateChangedCallback(cls): ...
    def getSortID(self): ...
    def isDraggable(self): ...
    def message(self): ...
    def updateDisplayData(self): ...
    def __del__(self) -> None: ...

class SceneGraphAttributeDataItem(UI4.Widgets.SceneGraphView.TreeWidgetItems.AttributeDataTreeWidgetItem):
    def getSortID(self): ...
    def shouldDrawGreyForeground(self): ...

class WarningMessageItem(MessageItem):
    AttributeName: ClassVar[str] = ...
    LocationType: ClassVar[str] = ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Utils.EventModule as EventModule
import NodegraphAPI
import NodegraphAPI_cmodule as NodegraphAPI_cmodule
import Utils as Utils
import typing
from typing import Set, Tuple

def DeleteNodeShapeAttr(node: NodegraphAPI.Node, attrName): ...
def GetAllActiveAttributeEditorNodes(): ...
def GetAllEditedNodes() -> list[NodegraphAPI.Node]: ...
def GetAllFloatingNodes() -> list[NodegraphAPI.Node]: ...
def GetAllSelectedNodes() -> list[NodegraphAPI.Node]: ...
def GetAllSelectedNodesAndParent(): ...
def GetAllThumbnailEnabledNodes(): ...
def GetMenuPath(nodeType): ...
def GetNodeComment(node: NodegraphAPI.Node) -> str: ...
def GetNodeModTime(node: NodegraphAPI.Node) -> int: ...
def GetNodeParameter(node: NodegraphAPI.Node, param): ...
def GetNodePosition(node: NodegraphAPI.Node) -> Tuple[int, int]: ...
def GetNodeShapeAttr(node: NodegraphAPI.Node, attrName): ...
def GetNodeShapeAttrs(node: NodegraphAPI.Node): ...
def GetViewNode() -> NodegraphAPI.Node | None: ...
def GetViewNodes() -> NodegraphAPI.Node | None: ...
def GetViewPortPosition(node: NodegraphAPI.GroupNode) -> Tuple[Tuple[int, int, int], Tuple[float, float, float]]: ...
def IsAttributeEditorNodeActive(node: NodegraphAPI.Node): ...
def IsNodeEdited(node: NodegraphAPI.Node) -> bool: ...
def IsNodeFloating(node: NodegraphAPI.Node) -> bool: ...
def IsNodeHidden(node: NodegraphAPI.Node): ...
def IsNodeLockedByParents(node: NodegraphAPI.Node | None) -> bool: ...
def IsNodeSelected(node: NodegraphAPI.Node) -> bool: ...
def IsNodeThumbnailEnabled(node: NodegraphAPI.Node): ...
def IsNodeViewed(node: NodegraphAPI.Node) -> bool: ...
def Register_NewNode_CB(fcn): ...
def SetAllSelectedNodes(nodelist: typing.Sequence[NodegraphAPI.Node]): ...
def SetAttributeEditorNodeActive(node: NodegraphAPI.Node, active): ...
def SetMenuPath(nodeType, path): ...
def SetNodeComment(node: NodegraphAPI.Node, comment): ...
def SetNodeEdited(node: NodegraphAPI.Node, edited: bool, exclusive: bool = ...): ...
def SetNodeFloating(node: NodegraphAPI.Node, flag: bool): ...
def SetNodeHidden(node: NodegraphAPI.Node, hide): ...
def SetNodeModTime(node: NodegraphAPI.Node, modTime: int): ...
def SetNodeParameter(node: NodegraphAPI.Node, param, value): ...
def SetNodePosition(node: NodegraphAPI.Node, xy: Tuple[int, int]): ...
def SetNodeSelected(node: NodegraphAPI.Node, selected: bool): ...
def SetNodeShapeAttr(node: NodegraphAPI.Node, attrName, attrValue): ...
def SetNodeShapeNodeAttrs(node: NodegraphAPI.Node, attrDict): ...
def SetNodeThumbnailEnabled(node: NodegraphAPI.Node, enabled): ...
def SetNodeViewed(node: NodegraphAPI.Node, viewed: bool, exclusive: bool = ...): ...
def SetViewPortPosition(node: NodegraphAPI.GroupNode, eyepoint: Tuple[int, int, int], viewscale: Tuple[float, float, float]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConditionalStateGrammar as ConditionalStateGrammar
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import re
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import Set, Tuple

_BooleanOps: list
_ComparisonOps: list
_ExtraHints: dict
_OpChildExpr: re.Pattern
_Parameter_XML: str

class NetworkMaterialInterfaceControls(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addChildOperator(self, opsGroup, operatorName): ...
    def addParameterHints(self, attrName, inputDict): ...
    def isResetPossible(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import Callbacks as Callbacks
import ConfigurationAPI_cmodule as Configuration
import PyUtilModule.FileUtils as FileUtils
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import PyUtilModule.ScenegraphBookmarkManager as ScenegraphBookmarkManager
import PyUtilModule.UndoEntries as UndoEntries
import Utils as Utils
import typing
from _typeshed import Incomplete
from typing import Set, Tuple

def CrashSave(forceSave: bool = ..., logCompletion: bool = ...): ...
def CrashSaveDisable(): ...
def CrashSaveEnable(): ...
def CreateSceneAsset(asset: str, versionUp: bool = ..., publish: bool = ..., extraOptionsDict: dict = ...) -> str: ...
def Export(fileNameOrAssetId: str, nodes: list[NodegraphAPI.Node], extraOptionsDict: Incomplete | None = ...) -> str: ...
def GetCrashActions() -> int: ...
def GetCrashTime() -> float: ...
def GetTimeOfFirstUnsavedAction() -> float | None: ...
def GetViableCrashFiles(smartPrune: bool = ...) -> list: ...
def Import(fileName: str, floatNodes: bool = ..., parentNode: Incomplete | None = ...) -> list[NodegraphAPI.Node]: ...
def IsFileDirty() -> bool: ...
def IsFileSavedAsAsset() -> bool: ...
def Load(fileName: str, isCrashFile: bool = ...): ...
def New(): ...
def Paste(nodeXML: str, parent: NodegraphAPI.GroupNode): ...
def PopFileDirtyState(): ...
def PostCreateSceneAsset(asset: str, versionUp: bool = ..., publish: bool = ..., extraOptionsDict: dict = ...) -> str: ...
def PushFileDirtyState(): ...
def RegisterPasteHandler(cb: typing.Callable): ...
def Revert(): ...
def Save(fileNameOrAssetId: str, extraOptionsDict: Incomplete | None = ...) -> str: ...
def SetFileDirty(): ...
def WasFileLoadedFromCrashFile() -> bool: ...
def WasFileVersionedOnLoad() -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import typing
from PyQt5.QtCore import Qt as Qt
from UI4.Util.LogRecordItemModel import LogRecordItemModel as LogRecordItemModel
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LogRecordTreeView(PyQt5.QtWidgets.QTreeView):
    activeLevelNamesChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    activeLevelsChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    kLevelNamesToLevels: ClassVar[dict] = ...
    kLevelsToLevelNames: ClassVar[dict] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _LogRecordTreeView__checkSortIndicatorChanged(self, column, order): ...
    def addEditingMenuItems(self, menu: PyQt5.QtWidgets.QMenu): ...
    def addViewingMenuItems(self, menu: PyQt5.QtWidgets.QMenu): ...
    def contextMenuEvent(self, event: PyQt5.QtGui.QContextMenuEvent): ...
    def getActiveLevelNames(self) -> list[str]: ...
    def getActiveLevels(self) -> set[int]: ...
    def getHighestRecordLevel(self) -> int: ...
    def getRecordLevels(self) -> set[int]: ...
    def isLevelFilterEnabled(self, level: int) -> bool: ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
    def on_copyAction_triggered(self): ...
    def on_deleteAction_triggered(self): ...
    def on_loggingLevelAction_toggled(self): ...
    def on_turnAllOffAction_triggered(self): ...
    def on_turnAllOnAction_triggered(self): ...
    def setActiveLevelNames(self, activeLevelNames: list[str]): ...
    def setActiveLevels(self, levels: typing.Iterable[int]): ...
    def setLevelFilter(self, level: int, enabled: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.Editors.NodeGroup
from typing import Set, Tuple

class ChannelsNodeFormWidget(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def _createChildWidget(self, policy, parentWidget, factory, index): ...
    def _popdownCreated(self, popdown): ...
    def getPopdownWidget(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

APPLICATION_ACTIVESHELF: str
APPLICATION_CODEFONTFAMILY: str
APPLICATION_CODEFONTSIZE: str
APPLICATION_DISMISSED_TAB_DEPRECATION_WARNINGS: str
APPLICATION_FONTFAMILY: str
APPLICATION_FONTSIZE: str
APPLICATION_MACRO_SAVE_PATH: str
APPLICATION_NODESPECIFICACTIVESHELF: str
APPLICATION_NUMBEROFRECENTPROJECTS: str
APPLICATION_NUMBEROFRECENTPROJECTS_MAX: int
APPLICATION_SCENEGRAPHACTIVESHELF: str
ATTRIBUTES: str
ATTRIBUTES_SHOW_INTERNAL_NODES_IN_ATTRIBUTE_HISTORY: str
CATALOG: str
CATALOG_COLUMNWIDTH: str
CATALOG_CREATE_PER_RENDER_PROJECT_SNAPSHOT: str
CATALOG_STATE: str
CATALOG_SYNC_TO_PROJECT_SETTINGS: str
COLOR: str
COLOR_ENABLE_DISPLAY_TRANSFORM_DEFAULT: str
COLOR_RESTRICT_RGBA_COMPONENTS_DEFAULT: str
COLOR_USE_SINGLE_COMPONENT_RGB: str
CRASHFILE: str
CRASHFILE_NUMBEROFACTIONS: str
CRASHFILE_TIME: str
DOCUMENTATION: str
DOCUMENTATION_SOURCE: str
DOPESHEET: str
DOPESHEET_SHOWTOOLTIPS: str
EXTERNAL_TOOLS: str
EXTERNAL_TOOLS_EDITOR: str
EXTERNAL_TOOLS_IMAGE_VIEWER: str
EXTERNAL_TOOLS_PDF_VIEWER: str
EXTERNAL_TOOLS_WEB_BROWSER: str
EXT_SUFFIX: str
ExpansionHandleColor: int
ExpansionHandleDraggedColor: int
ExpansionHandleHighlightColor: int
FLIPBOOK: str
FLIPBOOK_COLORSPACE: str
FLIPBOOK_FORMAT: str
HighlightColor: int
JoiningLineColor: int
LAYOUT: str
LAYOUT_DEFAULT: str
LAYOUT_HOTKEY1: str
LAYOUT_HOTKEY2: str
LAYOUT_HOTKEY3: str
LAYOUT_HOTKEY4: str
MANIPULATOR_LOCKEDCOLOR: str
MANIPULATOR_NORMALCOLOR: str
MANIPULATOR_SELECTCOLOR: str
MONITOR: str
MONITOR_ALLOW_KEYLESS_TABLET_INTERACTION: str
MONITOR_BGCOLOR: str
MONITOR_RENDER_ID_PASS: str
MONITOR_SHOW: str
MONITOR_SHOWSWIPELINE: str
MONITOR_SHOW_COLORTIMING: str
MONITOR_SHOW_COMMENT: str
MONITOR_SHOW_OVERLAY: str
MONITOR_SHOW_PIXEL_PROBE: str
MONITOR_SHOW_TEXT_RESOLUTION: str
MONITOR_SWIPELINECOLOR: str
NODEGRAPH: str
NODEGRAPH_ALLOW_KEYLESS_TABLET_INTERACTION: str
NODEGRAPH_AUTOCONNECTONCREATE: str
NODEGRAPH_AUTOSCROLL: str
NODEGRAPH_DEFAULT_VIEWSTATE: str
NODEGRAPH_DIMNONCONTRIBUTINGNODES: str
NODEGRAPH_DIMUNCONNECTEDTOVIEWNODE: str
NODEGRAPH_DRAWLOWCONTRAST: str
NODEGRAPH_FIND_ONLY_NODES_IN_THIS_GROUP_DEFAULT: str
NODEGRAPH_FLAGERRORSFILEIN: str
NODEGRAPH_FLAGERRORS_NODE_CONNECTION: str
NODEGRAPH_GRIDSNAP: str
NODEGRAPH_LOCKSTICKYNOTENODES: str
NODEGRAPH_NME_DIMDISCONNECTEDNODES: str
NODEGRAPH_NME_DIMEDITEDNODES: str
NODEGRAPH_NME_DIMNEWNODES: str
NODEGRAPH_NME_DIMUNCHANGEDNODES: str
NODEGRAPH_SHOWARROWS: str
NODEGRAPH_SHOWEXPRESSIONLINKS: str
NODEGRAPH_SHOWNODEICONS: str
NODEGRAPH_SHOWPAGESCONNECTEDONLY: str
NODEGRAPH_SHOWROLLOVERNODENAMES: str
NODEGRAPH_SHOWVIEWMASKS: str
NODEGRAPH_STICKYDRAG: str
NODEGRAPH_USE_COLOR_FROM_INPUT_PORT_FOR_CONNECTIONS: str
NODEMENU: str
NODEMENU_CATEGORIES: str
NODEMENU_DEFAULT_CATEGORIES: str
NODEMENU_RECENTCOUNT: str
NODEMENU_RECENTLIST: str
NODES: str
NODES_GAFFER: str
NODES_GAFFER_SYNC_SELECTION: str
NODES_LOOKFILEMANAGER: str
NODES_LOOKFILEMANAGER_ADDASLOOKFILEGLOBALSDEFAULT: str
PARAMETERS: str
PARAMETERS_CACHEEDITORS: str
PARAMETERS_OPENCELEDITORS: str
PARAMETERS_SELECT_LINE_EDIT_TEXT_ON_FOCUS: str
PARAMETERS_SINGLE_DIGIT_SCROLLING: str
PARAMETERS_STICKY_SCRUB: str
RECENTFILES: str
RENDERING: str
RENDERING_CONCURRENTRENDERS: str
RENDERING_RENDER_VARIABLES_PINNED_BY_DEFAULT: str
RENDERING_RESTART_LIVE_RENDER_ON_TIME: str
RENDERING_THREADS_2D: str
RENDERING_THREADS_3D: str
RENDERING_UPDATEMODE2D: str
RENDERING_UPDATEMODE3D: str
RENDERING_USE_THREAD_PREF: str
SCENEGRAPH: str
SCENEGRAPH_FIND_FILTERS: list
SCENEGRAPH_FIND_FILTER_ALL: str
SCENEGRAPH_FIND_FILTER_CAMERAS: str
SCENEGRAPH_FIND_FILTER_DEFAULT: str
SCENEGRAPH_FIND_FILTER_LIGHTS: str
SCENEGRAPH_FIND_FILTER_PINNED: str
SCENEGRAPH_FIND_FILTER_SELECTED: str
SCENEGRAPH_SHOWLIGHTSCOLUMN: str
SCENEGRAPH_SHOW_RENDER_COLUMN: str
SCENEGRAPH_SHOW_VIEWER_VISIBILITY_COLUMN: str
SCENEGRAPH_USER_COLUMN: str
SCENEGRAPH_USER_COLUMN_EXT: str
SplineColor: int
SplineHighlightColor: int
TERMINAL: str
TERMINAL_AUTOCOMPLETIONBEHAVIOR: str
TERMINAL_AUTOCOMPLETIONBEHAVIORS: list
TERMINAL_AUTOCOMPLETIONBEHAVIOR_IDE: int
TERMINAL_AUTOCOMPLETIONBEHAVIOR_SHELL: int
TERMINAL_AUTOINDENT: str
TERMINAL_COMMAND_AREA_BUFFER: str
TERMINAL_FORMATTER: str
TERMINAL_FORMATTERSTYLE: str
TERMINAL_HIGHLIGHTTRAILINGWHITESPACE: str
TERMINAL_RULERPOSITION: str
TERMINAL_SHOWRULER: str
TERMINAL_TOOLTIPS: str
TERMINAL_WORDWRAP: str
TangentArrowHeadColor: int
TangentColor: int
TangentDraggedColor: int
TangentHighlightColor: int
TangentLineColor: int
VIEWER: str
VIEWER_ANTIALIASING: str
VIEWER_BACKGROUND_COLOR: str
VIEWER_FACE_SELECTION_COLOR: str
VIEWER_FACE_SELECT_MODE_COLOR: str
VIEWER_MANIPULATION_FREEZE_PERIOD: str
VIEWER_MANIPULATORS: str
VIEWER_MANIPULATORS_SCALE: str
VIEWER_MONITOR_LAYER: str
VIEWER_MONITOR_LAYER_HIGHLIGHT_COLOR: str
VIEWER_MONITOR_LAYER_SELECTION_COLOR: str
VIEWER_SCREENWINDOW: str
VIEWER_SCREENWINDOW_COLOR: str
VIEWER_SCREENWINDOW_DASHED: str
VIEWER_SCREENWINDOW_LINEWIDTH: str
VIEWER_SELECTION_COLOR: str
VIEWER_SNAPPING: str
VIEWER_SNAPPING_AXIS_NORMAL_ORIENTATION: str
VIEWER_SNAPPING_AXIS_UP_ORIENTATION: str
VIEWER_SNAPPING_HIT_AREA_COLOR: str
VIEWER_SNAPPING_HIT_AREA_SIZE: str
VIEWER_SNAPPING_WIREFRAME_COLOR: str
VertexClosureColor: int
VertexColor: int
VertexHighlightColor: int
VertexSelectColor: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class LightLinkEditNode3D(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
from UI4.Tabs.NodeGraphTab.Layers.MenuLayer import MenuLayer as MenuLayer
from typing import Set, Tuple

_NODE_EXCLUDE_LIST: set
g_chosenNodeType: None
g_entries: list
kDeprecatedColor: tuple

class NodeCreationMenuLayer(MenuLayer):
    def _isNodeTypeVisible(self, nodeType: str) -> bool: ...
    def getBottomText(self): ...
    def getChosenValue(self): ...
    def getEntries(self): ...
    def onEntryChosen(self, value): ...
    def setEntries(self, entries): ...

def _on_nodegraph_registerType(eventType: str | None, eventID: object, type: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.NodeMaster.NodeInteractionDelegateManager as NodeInteractionDelegateManager
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4.NodeMaster.NodeInteractionDelegateManager
import Utils as Utils
from typing import Set, Tuple

class MaterialDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def __init__(self, editValue, inheritValue, nodeTypes, editParamName: str = ..., inheritParamName: str = ...) -> None: ...
    def _MaterialDelegate__dialogPrompt(self, nodeType, nameString): ...
    def _MaterialDelegate__editFromNodeReference(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialDelegate__editFromScenegraphLocation(self, targetNode, loc): ...
    def _MaterialDelegate__inheritFromNodeReference(self, targetNode, node: NodegraphAPI.Node): ...
    def _MaterialDelegate__inheritFromScenegraphLocation(self, targetNode, loc): ...
    def _MaterialDelegate__validNodeDrop(self, targetNode, event): ...
    def _MaterialDelegate__validScenegraphDrop(self, targetNode, event): ...
    def acceptsDrop(self, targetNode, event): ...
    def processDrop(self, targetNode, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import Set, Tuple

_ExtraHints: dict
_NaturalVis: dict
_Parameter_XML: str

class LookFileMaterialsIn(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def getInfoString(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PackageSuperToolAPI as PackageSuperToolAPI
import PackageSuperToolAPI.Packages
import PyFnAttribute
import PyFnGeolib
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import UI4 as UI4
import Utils as Utils
import ViewerAPI
import typing
from Callbacks.Callbacks import Callbacks as Callbacks
from PyUtilModule.VirtualKatana import ScenegraphManager as ScenegraphManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

GafferThreeListWatcher: _GafferThreeListWatcher

class _GafferThreeListWatcher(PyQt5.QtCore.QObject):
    listUpdated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def _GafferThreeListWatcher__on_event_idle(self): ...
    def _GafferThreeListWatcher__on_geolib_stateChanged(self): ...
    def _GafferThreeListWatcher__on_sceneAboutToLoad(self): ...
    @staticmethod
    def _GafferThreeListWatcher__processLocationData(locationData: PyFnGeolib.LocationData) -> PyFnAttribute.ConstVector | None: ...
    def _GafferThreeListWatcher__processLocationEvents(self): ...
    def _GafferThreeListWatcher__setList(self, newList): ...
    def _GafferThreeListWatcher__updateClient(self, viewNode: NodegraphAPI.Node | None): ...
    def getList(self) -> list[str]: ...

def AdoptforEditing(locations: list[str], gafferNode: PackageSuperToolAPI.BaseNode): ...
def BuildContextMenu(locations: list[str], selectedGafferNodeName: str, knownGafferNodeNames: list[str]) -> PyQt5.QtWidgets.QMenu: ...
def BuildDeleteActionLabel(packages: list[PackageSuperToolAPI.Packages.Package]) -> str: ...
def CanAdoptForEditing(locations: list[str], gafferNode: PackageSuperToolAPI.BaseNode) -> bool: ...
def CreateLightAtCameraPosition(gafferThreeNodeName: str, packageClassName: str, camera: ViewerAPI.ViewportCamera): ...
def CreateLightPackage(gafferThreeNode, packageClassName: str, position, rotation, centerOfInterest: float, shadowFallDistance: float): ...
def DeleteInGaffers(locations: list[str], gafferNodes: list[PackageSuperToolAPI.BaseNode]): ...
def DuplicateCurrentlySelectedLight(gafferThreeNodeName: str): ...
def FindGafferThreeNodeForLocation(location: str, boundingGafferName: Incomplete | None = ...): ...
def FindPackageForCurrentSelection(raiseOnMissing: bool = ..., includeEditPackages: bool = ...) -> PackageSuperToolAPI.Packages.Package | None: ...
def FindTemplateMaterialPathForLocation(location: str) -> str: ...
def GetDeletablePackagesInGaffers(locations: list[str], gafferNodes: list[PackageSuperToolAPI.BaseNode]) -> typing.Iterator[PackageSuperToolAPI.Packages.Package]: ...
def GetIcon(iconName) -> PyQt5.QtGui.QIcon: ...
def GetIconPixmaps(iconName) -> None: ...
def GetLightPackageIcon(packageClass: object, iconSize: int = ...) -> PyQt5.QtGui.QIcon: ...
def GetMaterialMetaFromAttributes(attrs: PyFnAttribute.GroupAttribute): ...
def GetParametersHashFromAttributes(attrs: PyFnAttribute.GroupAttribute) -> int: ...
def GetPotentialChildren(location: str) -> list: ...
def GetRenamablePackage(locations: list[str], gafferNode: PackageSuperToolAPI.BaseNode) -> PackageSuperToolAPI.Packages.Package | None: ...
def GetViewerParametersFromAttributes(attrs: PyFnAttribute.GroupAttribute): ...
def ProvideLightPackageWithTemplateMaterial(lightPackage: PackageSuperToolAPI.Packages.Package) -> TemplateMaterialPackage: ...
def ShowRenameDialog(package: PackageSuperToolAPI.Packages.Package): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FilterFieldWidget(PyQt5.QtWidgets.QFrame):
    filterUpdate: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, name: str = ..., filterTypes: Incomplete | None = ..., yellowClearIcon: bool = ...) -> None: ...
    def _FilterFieldWidget__clearFilterField(self): ...
    def clear(self): ...
    def getFilterField(self): ...
    def getFilterText(self): ...
    def getFilterType(self): ...
    def signalUpdate(self, text: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from typing import Set, Tuple

class HideTitleGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _buildTopAreaLayout(self, layout): ...
    def hideTitle(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Version.Utils as Utils
from typing import Set, Tuple

VERSION_SCRIPT_TYPE_XML: int
VERSION_SCRIPT_TYPE_XMLIO: int

def GetCurrentNodeTypeVersion(nodeTypeName): ...
def GetFcnStack(oldVersion, currentVersion): ...
def GetNodeTypeVersionUpdateFunctions(nodeTypeName, nodeTypeVersionToUpdate): ...
def HasAnyNodeTypeVersionUpdateFunctions(): ...
def RegisterVersionScript(versionTag, fcn, scriptType): ...
def SetCurrentNodeTypeVersion(nodeTypeName, currentNodeTypeVersion): ...
def SetNodeTypeVersionUpdateFunction(nodeTypeName, nodeTypeVersion, fnc): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

class GroupGuard:
    def __init__(self, settings, name) -> None: ...
    def __enter__(self): ...
    def __exit__(self, excType, excValue, tb): ...

def RestoreGeometry(settings, widget, groupName: str = ...): ...
def SaveGeometry(settings, widget, groupName: str = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import MachineInfo as MachineInfo
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import UI4 as UI4
import Utils as Utils
from Callbacks.Callbacks import Callbacks as Callbacks
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from _typeshed import Incomplete
from typing import Set, Tuple

class PreferenceValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent: Incomplete | None = ..., name: str = ...) -> None: ...
    def getChildByName(self, name): ...
    def getChildren(self): ...
    def getName(self): ...
    def getNumChildren(self): ...
    def getPrefType(self): ...
    def getType(self): ...
    def getValue(self) -> Tuple[float, int | str]: ...
    def getWidgetHints(self): ...
    def restoreOldValues(self): ...
    def saveOldValues(self): ...
    def setValue(self, value: Tuple[float, int | str], final: bool = ...) -> bool: ...

class PreferencesDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, *args, **kwargs) -> None: ...
    def accept(self): ...
    def reject(self): ...
    def selectItem(self, category): ...

class PreferencesEditor(PyQt5.QtWidgets.QWidget):
    def __init__(self, *args) -> None: ...
    def _PreferencesEditor__currentItemChanged(self, item): ...
    def buildPrefFrame(self, prefName): ...
    def rebuildContent(self, keepItems: bool = ...): ...
    def revert(self): ...
    def selectItem(self, itemName): ...
    def showEvent(self, event): ...
    def store(self): ...

def ApplyPreferences(): ...
def ShowPreferencesDialog(*args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import Nodes2DAPI as Nodes2DAPI
import PyOpenColorIO as OCIO
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.ComboBoxNoWheel import ComboBoxNoWheel as ComboBoxNoWheel
from _typeshed import Incomplete
from typing import Set, Tuple

class ColorspaceSelectionWidget(OptionComboBase):
    def __init__(self, parent, default: Incomplete | None = ...) -> None: ...

class ExrBitDepthWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class ExrCompressionWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class ImageOptionsWidget(PyQt5.QtWidgets.QWidget):
    def __init__(self, parent, defaultExtension: str = ..., defaultValue: Incomplete | None = ...) -> None: ...
    def setColorspace(self, csname): ...
    def setExtension(self, extension): ...
    def setValue(self, optionsDict): ...
    def value(self): ...

class JpgQualityWidget(PyQt5.QtWidgets.QSpinBox):
    def __init__(self, parent, default: str = ...) -> None: ...
    def setValue(self, value): ...
    def value(self): ...

class OptionComboBase(ComboBoxNoWheel):
    def __init__(self, parent, optionList, default) -> None: ...
    def setOptions(self, optionList): ...
    def setValue(self, option): ...
    def value(self): ...

class OutputImageExtensionWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class PngBitDepthWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class RlaBitDepthWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class TifBitDepthWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...

class TifCompressionWidget(OptionComboBase):
    def __init__(self, parent, default: str = ...) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from typing import ClassVar, Set, Tuple

class NameItemDelegate(BaseItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    PolishOpAttributeName: ClassVar[str] = ...
    TopLevelLocation: ClassVar[str] = ...
    _NameItemDelegate__customIcons: ClassVar[dict] = ...
    _NameItemDelegate__greyColor: ClassVar[None] = ...
    _NameItemDelegate__pinnedPixmaps: ClassVar[dict] = ...
    _NameItemDelegate__visibilityPixmaps: ClassVar[dict] = ...
    def _NameItemDelegate__applyCustomIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, locationType: str, isVisible: int, localVisible: bool, isPinned: bool, childrenPinned: bool): ...
    def _NameItemDelegate__applyIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, icon: PyQt5.QtGui.QIcon, width: int, height: int): ...
    def _NameItemDelegate__applySceneGraphLocationTypeIcon(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, locationType: str): ...
    def _NameItemDelegate__createPinnedPixmap(self, pinned: bool, childrenPinned: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__createVisibilityPixmap(self, visible: int, local: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__getAttributePixmapKey(self, attributeValue: int, local: bool, height: float) -> str: ...
    def _NameItemDelegate__getPinnedPixmap(self, pinned: bool, childrenPinned: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _NameItemDelegate__getPinnedStatus(self, locationPath: str) -> tuple[bool, bool]: ...
    def _NameItemDelegate__getVisibilityPixmap(self, visible: int, local: bool, height: int) -> PyQt5.QtGui.QPixmap: ...
    def _applyIconDecorations(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def _getGreyColor(self) -> None: ...
    def _isMuted(self, locationPath: str) -> bool: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def shouldShowPinning(self) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
from Utils.EventModuleCommon import GetAllRegisteredEventTypes as GetAllRegisteredEventTypes, GetNumRegisteredHandlersForEventType as GetNumRegisteredHandlersForEventType, IsCollapsedHandlerRegisteredAfterEventLoop as IsCollapsedHandlerRegisteredAfterEventLoop, IsCollapsedRegistered as IsCollapsedRegistered, IsEventFilterRegistered as IsEventFilterRegistered, IsHandlerRegistered as IsHandlerRegistered, IsHandlerRegisteredAfterEventLoop as IsHandlerRegisteredAfterEventLoop, IsHandlerRegisteredForEventType as IsHandlerRegisteredForEventType, RegisterCollapsedHandler as RegisterCollapsedHandler, RegisterEventFilter as RegisterEventFilter, RegisterEventHandler as RegisterEventHandler, SetRegistrationCallbackForType as SetRegistrationCallbackForType, UnregisterCollapsedHandler as UnregisterCollapsedHandler, UnregisterEventFilter as UnregisterEventFilter, UnregisterEventHandler as UnregisterEventHandler, UnregisterObjectEventHandlers as UnregisterObjectEventHandlers
from Utils.EventModuleDefault import Initialize as Initialize, ProcessAllEvents as ProcessAllEvents, ProcessEvents as ProcessEvents, PumpIdleQueue as PumpIdleQueue, QueueEvent as QueueEvent, QueuePriorityEvent as QueuePriorityEvent
from typing import Set, Tuple

def RegisterDebugEventHandler(): ...
def SynchronousEventProcessingScope(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

NodegraphEventTypes: dict
kManualUpdateEventsKey: int
kNodePortChangeEventsKey: int
kNodegraphEventsKey: int
kParamChangedEventsKey: int
kParamPenUpEventsExclusionsKey: int
kPortConnectionEventsKey: int

def GetNodegraphEventTypes(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI_cmodule
import PyFnAttribute
import PyXmlIO
import types
import typing
from . import Views as Views
from typing import Any, Set, Tuple, overload

RENDER_TYPE_IDLE: int
RENDER_TYPE_PRIMARY: int
TILE_PRIORITIZER_NONE: int
TILE_PRIORITIZER_SCANLINE: int
TILE_PRIORITIZER_SPIRAL: int
__cleanup: PyCapsule

class FrameBuffer:
    def __init__(self, filename: str, sampleRateX: float, sampleRateY: float, nodeName: str, renderTime: float, isRender3D: bool) -> None: ...
    def copyImageData(self, data: object, rect: list[tuple[int, int, int, int]], rowBytes: int, numChannels: int) -> None: ...
    def dirtyBufferRects(self, updateRects: typing.Sequence, texturePool: dict) -> bool: ...
    def duplicate(self) -> FrameBuffer: ...
    def getBackgroundColor(self) -> tuple: ...
    def getBackgroundRegion(self) -> list: ...
    def getChannels(self) -> str: ...
    def getDataRegion(self) -> list: ...
    def getDataRegionOutline(self) -> list[Tuple[int, int, int, int]]: ...
    def getDataWindow(self) -> tuple: ...
    def getDisplayWindow(self) -> tuple: ...
    def getFrameTime(self) -> float: ...
    def getNativeDataWindow(self) -> tuple: ...
    def getNodeName(self) -> str: ...
    def getSampleRate(self) -> tuple: ...
    def getSequenceID(self) -> int: ...
    def getSize(self) -> int: ...
    def getThumbnailData(self, width: int = ..., forceRegenerate: bool = ...) -> bytes: ...
    def getThumbnailHeight(self) -> int: ...
    def getThumbnailWidth(self) -> int: ...
    def getTiles(self, clipWindow: list[tuple[int, int, int, int]], adjustClipWindowForProxyScale: bool = ...) -> list: ...
    def getView(self) -> str: ...
    def glTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int) -> None: ...
    def isFirstInConnection(self) -> bool: ...
    def isRender3D(self) -> bool: ...
    def queryHistogram(self, rect: list[tuple[int, int, int, int]], binMin: list[tuple[float, float, float, float]], binMax: list[tuple[float, float, float, float]], size: int, colorspace: str) -> dict: ...
    def queryRegionStats(self, rect: list[tuple[int, int, int, int]], ignoreNanInfValues: bool = ..., minInfValue: object = ..., maxInfValue: object = ...) -> dict: ...
    def queryScanline(self, scanline: int, isHorizontal: bool, colorspace: str = ..., lutForward: int = ...) -> dict: ...
    def setSequenceID(self, id: int) -> None: ...
    def setView(self, view: str) -> None: ...
    def writeToDisk(self, filename: str, args: dict, width: int, height: int, writeID: bool) -> None: ...
    def __hash__(self) -> int: ...

class IntImage:
    def __init__(self) -> None: ...
    def channels(self) -> int: ...
    def height(self) -> int: ...
    def imageData(self) -> Any: ...
    def width(self) -> int: ...
    def __hash__(self) -> int: ...

class Node2D(NodegraphAPI_cmodule.Node):
    def __init__(self) -> None: ...

def CancelRender(renderType: int, stallOnCompletion: bool) -> None: ...
def CheckExternalRender() -> None: ...
def CheckFileIns(nodeNames: list[str], renderTime: float) -> list: ...
def ClearDisplayWindowCache() -> None: ...
def ClearImageHeaderCache() -> None: ...
def ClearSpeculativeCacheContents() -> None: ...
def ConvertUpdateRectsToFnAttribute(arg0: list[list[tuple[int, int, int, int]]]) -> PyFnAttribute.IntAttribute: ...
def CreateExternalRenderListener(port: int) -> None: ...
def EnumerateReadableImageFormats() -> list: ...
def EnumerateWriteableImageFormats() -> list: ...
def FinishRender(arg0) -> None: ...
def GetAllRenderTypes() -> tuple: ...
@overload
def GetDisplayWindow(port: NodegraphAPI_cmodule.Port, graphState: NodegraphAPI_cmodule.GraphState) -> tuple: ...
@overload
def GetDisplayWindow(port: NodegraphAPI_cmodule.Port, time: float) -> tuple: ...
def GetErrorMessages() -> tuple: ...
def GetExternalRenderListenerInfo() -> Any: ...
def GetFileOutAssetId(node: Node2D, inputIndex: int, graphState: NodegraphAPI_cmodule.GraphState, includeRep: bool) -> str: ...
def GetFileOutColorspace(node: Node2D, inputIndex: int) -> str: ...
def GetFileOutEnabled(node: Node2D, inputIndex: int) -> bool: ...
def GetFileOutFilename(node: Node2D, inputIndex: int, graphState: NodegraphAPI_cmodule.GraphState, resolveFrame: bool = ...) -> str: ...
def GetFileOutFormat(node: Node2D, inputIndex: int) -> str: ...
def GetFileOutOutputParams() -> str: ...
def GetFileOutPassName(node: Node2D, graphState: NodegraphAPI_cmodule.GraphState) -> str: ...
def GetFileOutPostScriptInfo(node: Node2D, scriptIndex: int, graphState: NodegraphAPI_cmodule.GraphState) -> dict: ...
def GetFileOutPostScriptParams() -> str: ...
def GetFileOutProxyOnCue(node: Node2D, inputIndex: int) -> bool: ...
def GetFileOutRepPrefix(node: Node2D, inputIndex: int) -> str: ...
def GetFileOutRepresentation(node: Node2D, inputIndex: int, graphState: NodegraphAPI_cmodule.GraphState, includeExtension: bool) -> str: ...
def GetFileOutResolutionName(node: Node2D, inputIndex: int, graphState: NodegraphAPI_cmodule.GraphState) -> str: ...
def GetFilmWidthFromString(filmBack: str) -> float: ...
def GetFrameBufferCancelledMessages() -> tuple: ...
def GetFrameBufferCompletedMessages() -> tuple: ...
def GetFrameBufferRectUpdateMessages() -> dict: ...
def GetImageDescription(filename: str) -> dict: ...
def GetImageDiskUsage() -> int: ...
def GetImageMemoryUsage() -> int: ...
def GetImageReadPath(node: Node2D, renderTime: float) -> str: ...
def GetIncrementedRenderSequenceID() -> int: ...
def GetMaxDiskUsage() -> int: ...
def GetMaxImageMemory() -> int: ...
def GetNewFrameBuffers() -> list: ...
@overload
def GetOutputDisplayWindow(port: NodegraphAPI_cmodule.Port, graphState: NodegraphAPI_cmodule.GraphState) -> tuple: ...
@overload
def GetOutputDisplayWindow(port: NodegraphAPI_cmodule.Port, time: float) -> tuple: ...
def GetRenderMessages() -> list: ...
def GetRenderProgressMessages() -> list: ...
def GetRenderTerminationSignal(rendererName: str) -> int: ...
def GetRenderThreads() -> int: ...
def GetSpeculativeCacheContents() -> PyXmlIO.Element: ...
def GetSpeculativeCacheEnabled() -> bool: ...
def GetTileRenderOrderMessages() -> dict: ...
def GetTileSize() -> tuple: ...
def GetTransformBetweenNodes(src: NodegraphAPI_cmodule.Node, dst: NodegraphAPI_cmodule.Node, time: float) -> tuple: ...
def GetTransformForInputPort(inputPort: NodegraphAPI_cmodule.Port, time: float) -> tuple: ...
def IsExternalRenderInProgress(sequenceID: int) -> bool: ...
def IsRenderInProgress() -> bool: ...
def IsThumbnailRendering() -> bool: ...
def KillExternalRender(sequenceID: int, waitOnCompletion: bool) -> None: ...
def NotifyBufferChanged(buffer: FrameBuffer) -> None: ...
def PrintImageMemoryUsage() -> None: ...
def QueueErrorMessage(sequenceID: int, errorCode: int, nodeName: str, message: str) -> None: ...
def QueueRenderMessage(sequenceID: int, message: str) -> None: ...
def ReadImage(filename: str, scale: float) -> Any: ...
def ReadImageThreaded(filename: str, mipSizeX: int, mipSizeY: int, callback: typing.Callable = ..., tileLocation: object = ...) -> bool: ...
def RegisterNukeSession(serviceHost: str, servicePort: int, catalogRegistryHost: str, catalogRegistryPort: int, mainSequenceID: int, previewComp: bool, mappings: list[Tuple[str, int, str, int, FrameBuffer]]) -> None: ...
def Render(ports: list[NodegraphAPI_cmodule.Port], buffers: list[FrameBuffer], rois: list[typing.Sequence], names: list[str], renderTaskIDs: list[int], views: list[str], outputTime: float, sampleRateX: float, sampleRateY: float, hotRender: bool, interactive: bool, emitRenderTileOrdering: bool, diskCachingAllowed: bool, tilePrioritizerType: int, tilePrioritizerCenter: object, tilePrioritizerRect: object, interactiveOverscanPadding: object, renderType: int, renderMethodName: str) -> tuple: ...
def RenderThumbnail(port: NodegraphAPI_cmodule.Port, renderTime: float, proxyScaleX: float, proxyScaleY: float, nodeName: str, maxWidth: int, maxHeight: int, ignoreCacheID: str) -> str: ...
def RestartExternalRender(sequenceID: int) -> None: ...
def SetCatalogEventReceiver(callable: typing.Callable) -> None: ...
def SetMaxDiskUsage(sizeInMegabytes: int) -> None: ...
def SetMaxImageMemory(sizeInMegabytes: int) -> None: ...
def SetNukeSessionMappings(mainSequenceID: int, mappings: list[Tuple[str, int, str, int, FrameBuffer]]) -> None: ...
def SetNukeSessionOutputNodeName(mainSequenceID: int, outputNodeName: str) -> None: ...
def SetRenderDebug(enabled: bool) -> None: ...
def SetRenderLogFile(filename: str) -> None: ...
def SetRenderThreads(numThreads: int) -> None: ...
def SetSpeculativeCacheEnabled(enabled: bool) -> None: ...
def SetTileSize(width: int, height: int) -> None: ...
def SignalExternalRender(sequenceID: int, signal: int) -> None: ...
def StartExternalRender(rendererName: str, sequenceID: int, nodeName: str, preCommands: list[str], renderCommand: str, postCommands: list[str], isRemoteRender: bool, renderFarm: str) -> tuple: ...
def TerminateCancelledRenders() -> None: ...
def TileStitch(xTiles: int, yTiles: int, inputFilenames: list[str], outputImageOptions: str, outputFilename: dict, outputDataRect: list[tuple[int, int, int, int]], outputDisplayRect: list[tuple[int, int, int, int]], clampOutput: bool, colorConvert: bool, computeStats: str) -> None: ...
def UnregisterNukeSession(mainSequenceID: int) -> None: ...
def _Register2DFactories() -> None: ...
def _Set_GetRenderProducer_Fn(callable: typing.Callable) -> None: ...
def _internalRegisterCommandLineNode(nodeType: str, paramXML: str, ctor: typing.Callable) -> None: ...
def _internalSetFarmPluginManager(farmManagerModule: types.ModuleType) -> None: ...
def fbo_bind(arg0: int) -> None: ...
def fbo_create(arg0: int, arg1: int) -> tuple: ...
def fbo_delete(arg0: int) -> None: ...
def fbo_init() -> None: ...
def fbo_unbind() -> None: ...
def glBatchVertex(vertexSequence: typing.Sequence) -> None: ...
def glDrawProjectedLatLongLine(startPt: list[tuple[float, float, float]], endPt: list[tuple[float, float, float]], latLngWidthHeight: list[tuple[float, float]], subdivisions: int) -> None: ...
def gl_disableFragmentProgram() -> None: ...
def gl_enableFilmlookFragmentProgram(displayRequest: dict[str, object], textureID: int) -> None: ...
def gl_enableFragmentProgram(fragmentProgram: str, textureID: int) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class LineNumberAreaWidget(PyQt5.QtWidgets.QWidget):
    kBackgroundColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kCurrentLineTextColor: ClassVar[PyQt5.QtGui.QColor] = ...
    kTextColor: ClassVar[PyQt5.QtGui.QColor] = ...
    def __init__(self, textEdit) -> None: ...
    def _LineNumberAreaWidget__getDigitCount(self): ...
    def _LineNumberAreaWidget__getDigitWidth(self): ...
    def _LineNumberAreaWidget__getMargin(self): ...
    def _LineNumberAreaWidget__on_textEdit_cursorPositionChanged(self): ...
    def _LineNumberAreaWidget__on_textEdit_documentUpdated(self, rect: Incomplete | None = ...): ...
    def _LineNumberAreaWidget__on_textEdit_selectionChanged(self): ...
    def _LineNumberAreaWidget__updateGeometry(self): ...
    def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def AddLayer(color: Incomplete | None = ..., label: str = ...): ...
def ClearAll(): ...
def DeleteLayer(index): ...
def GetLayerName(index): ...
def GetLayers(): ...
def GetRoot(): ...
def ReorderLayer(oldPos, newPos): ...
